@@ -9,22 +9,22 @@
 //  Module:         Multithreaded AEWF (AEWF = Advanced EWF)
 // ****************************************************************************
 
-// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014 Guy Voncken
+// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016 Guy Voncken
 //
-// This file is part of guymager.
+// This file is part of Guymager.
 //
-// guymager is free software: you can redistribute it and/or modify
+// Guymager is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation, either version 2 of the License, or
 // (at your option) any later version.
 //
-// guymager is distributed in the hope that it will be useful,
+// Guymager is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with guymager. If not, see <http://www.gnu.org/licenses/>.
+// along with Guymager. If not, see <http://www.gnu.org/licenses/>.
 
 #include "common.h"
 #include "compileinfo.h"
@@ -33,6 +33,7 @@
 #include <string.h>
 #include <time.h>    //lint !e537 repeated include file
 #include <stdlib.h>
+#include <errno.h>
 #include <zlib.h>
 #include <libewf.h>
 
@@ -77,6 +78,7 @@ const char * AEWF_SECTIONNAME_TABLE2  = "table2" ;
 const char * AEWF_SECTIONNAME_DATA    = "data"   ;
 const char * AEWF_SECTIONNAME_ERROR2  = "error2" ;
 const char * AEWF_SECTIONNAME_HASH    = "hash"   ;
+const char * AEWF_SECTIONNAME_DIGEST  = "digest" ;
 const char * AEWF_SECTIONNAME_NEXT    = "next"   ;
 const char * AEWF_SECTIONNAME_DONE    = "done"   ;
 
@@ -164,42 +166,50 @@ typedef struct
    uint  CRC;
 } __attribute__ ((packed)) t_AewfSectionHashContents;
 
+typedef struct
+{
+   uchar MD5    [16];
+   uchar SHA1   [20];
+   uchar Padding[40];
+   uint  CRC;
+} __attribute__ ((packed)) t_AewfSectionDigestContents;
+
 class t_Aewf
 {
    public:
-      QString          SegmentFilename;      // The base path and filename, without extension
-      quint64          DeviceSize;
-      quint64          SegmentSize;
-      quint64          ChunkSize;
-      quint64          SectorSize;
-      t_AewfMediaType  MediaType;
-      t_AewfMediaFlags MediaFlags;
-      QString          Description;
-      QString          CaseNumber;
-      QString          EvidenceNumber;
-      QString          Examiner;
-      QString          Notes;
-      QString          DeviceModel;
-      QString          SerialNumber;
-      QString          ImagerVersion;
-      QString          OSVersion;
+      QString           SegmentFilename;      // The base path and filename, without extension
+      quint64           DeviceSize;
+      quint64           SegmentSize;
+      quint64           ChunkSize;
+      quint64           SectorSize;
+      t_AewfMediaType   MediaType;
+      t_AewfMediaFlags  MediaFlags;
+      QString           Description;
+      QString           CaseNumber;
+      QString           EvidenceNumber;
+      QString           Examiner;
+      QString           Notes;
+      QString           DeviceModel;
+      QString           SerialNumber;
+      QString           ImagerVersion;
+      QString           OSVersion;
 
-      uint             SegmentFiles;
-//      uchar            EwfCompressionLevel;   // The compression levels have been made global in order not to depend upon
-//      int              ZipCompressionLevel;   // Aewf handle in preprocessing (this simplifies duplicate image writing)
-      QStringList      SegmentFilenameList;
-      FILE           *pCurrentSegmentFile;
-      quint64          CurrentSectionSectorSeekPos;
-      quint64          CurrentSectionSectorContentSize;
-      t_AewfFileHeader FileHeaderCache;
-      quint64          ChunkBaseOffset;
-      uint             ChunkOffsetArr[AEWF_MAX_CHUNK_OFFSETS+1];  // Data is stored in little endian for speed optimisation here! +1 as we add a fake chunk offset marking the end of the section "sectors" when verifying the data
-      uint             ChunkOffsets;
-      uint             CurrentChunkOffset;           // For knowing the current chunk during verification
+      uint              SegmentFiles;
+//      uchar             EwfCompressionLevel;   // The compression levels have been made global in order not to depend upon
+//      int               ZipCompressionLevel;   // Aewf handle in preprocessing (this simplifies duplicate image writing)
+      QStringList       SegmentFilenameList;
+      FILE            *pCurrentSegmentFile;
+      quint64           CurrentSectionSectorSeekPos;
+      quint64           CurrentSectionSectorContentSize;
+      t_AewfFileHeader  FileHeaderCache;
+      quint64           ChunkBaseOffset;
+      uint              ChunkOffsetArr[AEWF_MAX_CHUNK_OFFSETS+1];  // Data is stored in little endian for speed optimisation here! +1 as we add a fake chunk offset marking the end of the section "sectors" when verifying the data
+      uint              ChunkOffsets;
+      uint              CurrentChunkOffset;           // For knowing the current chunk during verification
 
-      t_HashContextMD5 CurrentSegmentHashContextMD5; // For segment file MD5 calculation during verification
-      uchar          *pVerifyBuffer;                 // For uncompression and other verification tasks
-      uint             VerifyBufferLen;
+      t_HashContextMD5  CurrentSegmentHashContextMD5;  // For segment file MD5 calculation during verification
+      uchar           *pVerifyBuffer;                  // For uncompression and other verification tasks
+      uint              VerifyBufferLen;
 
       t_Aewf ()
       {
@@ -446,21 +456,30 @@ static APIRET AewfCreateFile (t_Aewf *pAewf)
 static APIRET AewfCloseFile (t_pAewf pAewf)
 {
    FILE *pCurrentSegmentFile = pAewf->pCurrentSegmentFile;
+   int    rc, err;
 
    if (pCurrentSegmentFile == NULL)
       CHK (ERROR_AEWF_NO_FILE_OPEN)
 
    pAewf->pCurrentSegmentFile = NULL;
 
-   if (fflush (pCurrentSegmentFile))
+   rc = fflush (pCurrentSegmentFile);
+   if (rc)
    {
-      (void) fclose (pCurrentSegmentFile);
+      err = errno;
+      LOG_ERROR ("fflush returned %d (errno %d - %s)", rc, err, strerror(err));
+
+      (void) UtilClose (pCurrentSegmentFile);
       CHK (ERROR_AEWF_CANNOT_FLUSH_FILE)
    }
 
-   if (fclose (pCurrentSegmentFile))
+   rc = UtilClose (pCurrentSegmentFile);
+   if (rc)
+   {
+      err = errno;
+      LOG_ERROR ("UtilClose returned %d (errno %d - %s)", rc, err, strerror(err));
       CHK (ERROR_AEWF_CANNOT_CLOSE_FILE)
-
+   }
 // Simulate cases close error
 //   static int FakeCloseError=0;
 //   if (FakeCloseError++ == 2)
@@ -700,6 +719,20 @@ static APIRET AewfWriteSectionHash (t_Aewf *pAewf, const uchar *pMD5)
    return NO_ERROR;
 }
 
+static APIRET AewfWriteSectionDigest (t_Aewf *pAewf, const uchar *pMD5, const uchar *pSHA1)
+{
+   t_AewfSectionDigestContents DigestContents;
+
+   memset (&DigestContents, 0, sizeof(DigestContents));
+   memcpy (DigestContents.MD5 , pMD5 , sizeof(DigestContents.MD5 ));
+   memcpy (DigestContents.SHA1, pSHA1, sizeof(DigestContents.SHA1));
+   DigestContents.CRC = qToLittleEndian (AewfCRC (&DigestContents, offsetof (t_AewfSectionDigestContents, CRC)));
+
+   CHK (AewfWriteSection (pAewf, AEWF_SECTIONNAME_DIGEST, &DigestContents, sizeof(DigestContents)))
+   return NO_ERROR;
+}
+
+
 static APIRET AewfWriteSectionNext (t_Aewf *pAewf)
 {
    CHK (AewfWriteSection (pAewf, AEWF_SECTIONNAME_NEXT, NULL, 0))
@@ -840,6 +873,7 @@ APIRET AewfWrite (t_Aewf *pAewf, t_AewfPreprocess *pPreprocess, const uchar *pDa
                     + 2 * SectionTableSize                                              // Sections "table" and "table2"
                     +     sizeof (t_AewfSection) + sizeof (t_AewfSectionVolumeContents) // Section "data"
                     +     sizeof (t_AewfSection) + sizeof (t_AewfSectionHashContents  ) // Section "hash"
+                    +     sizeof (t_AewfSection) + sizeof (t_AewfSectionDigestContents) // Section "digest"
                     +     sizeof (t_AewfSection)                                        // Section "done"
                     +     sizeof (t_AewfSection) +                                      // In case we need to start a new section "sectors" (see below),
                     + 2 * sizeof (t_AewfSection) + sizeof (t_AewfSectionTableContents); // which would also require additonal sections "table" and "table2"
@@ -890,7 +924,7 @@ APIRET AewfWrite (t_Aewf *pAewf, t_AewfPreprocess *pPreprocess, const uchar *pDa
    return NO_ERROR;
 }
 
-APIRET AewfClose (t_pAewf *ppAewf, QList<quint64> &BadSectors, const uchar *pMD5, const uchar */*pSHA1*/, const uchar */*pSHA256*/)
+APIRET AewfClose (t_pAewf *ppAewf, QList<quint64> &BadSectors, const uchar *pMD5, const uchar *pSHA1, const uchar */*pSHA256*/)
 {
    t_Aewf *pAewf = *ppAewf;
 
@@ -908,8 +942,9 @@ APIRET AewfClose (t_pAewf *ppAewf, QList<quint64> &BadSectors, const uchar *pMD5
       if (BadSectors.count())
          CHK (AewfWriteSectionError (pAewf, BadSectors))
 
-      CHK (AewfWriteSectionHash (pAewf, pMD5))
-      CHK (AewfWriteSectionDone (pAewf))
+      CHK (AewfWriteSectionDigest (pAewf, pMD5, pSHA1))
+      CHK (AewfWriteSectionHash   (pAewf, pMD5))
+      CHK (AewfWriteSectionDone   (pAewf))
 
       CHK (AewfCloseFile (pAewf))
    }
@@ -1107,7 +1142,6 @@ APIRET AewfReadNextChunk (t_Aewf *pAewf, uchar *pData, uint *pDataLen, QString *
    bool    IsSectors = false;
    bool    IsEof     = false;  // end of file
    bool    IsEoi     = false;  // end of image
-//   int     rc;
    APIRET  rc;
    uLongf  DataLen;
 
@@ -1155,9 +1189,13 @@ APIRET AewfReadNextChunk (t_Aewf *pAewf, uchar *pData, uint *pDataLen, QString *
       while (!IsSectors && !IsEof && !IsEoi);
       if (IsEof || IsEoi)
       {
-//         printf ("\nClosing current file");
-         if (fclose (pAewf->pCurrentSegmentFile))
+         int ret = UtilClose (pAewf->pCurrentSegmentFile);
+         if (ret)
+         {
+            int err = errno;
+            LOG_ERROR ("UtilClose returned %d (errno %d - %s)", ret, err, strerror(err));
             CHK_LOG (pAewf, ERROR_AEWF_CANNOT_CLOSE_FILE)
+         }
          pAewf->pCurrentSegmentFile = NULL;
 
          *pDataLen         = 0;
