@@ -9,29 +9,29 @@
 //  Module:         Application configuration data
 // ****************************************************************************
 
-// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014 Guy Voncken
+// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016 Guy Voncken
 //
-// This file is part of guymager.
+// This file is part of Guymager.
 //
-// guymager is free software: you can redistribute it and/or modify
+// Guymager is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation, either version 2 of the License, or
 // (at your option) any later version.
 //
-// guymager is distributed in the hope that it will be useful,
+// Guymager is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with guymager. If not, see <http://www.gnu.org/licenses/>.
+// along with Guymager. If not, see <http://www.gnu.org/licenses/>.
 
 #include "common.h"
 
 #include <limits.h>
 #include <unistd.h>
 
-//#include "proc/sysinfo.h"  // Required in order to get smp_num_cpus for finding out the number of CPUs in the system
+
 
 #include <qcolor.h>
 #include <qfont.h>
@@ -277,6 +277,7 @@ static t_ToolCfgSet SetArrEwfFormat[] =
    #if (LIBEWF_VERSION >= 20130416)
    {  "Encase7" ,         LIBEWF_FORMAT_ENCASE7},
    {  "Linen7"  ,         LIBEWF_FORMAT_LINEN7 },
+   {  "EWFX"    ,         LIBEWF_FORMAT_EWFX   },
    #endif
    {  "Guymager",         t_File::AEWF         }, // AEWF format is a format on its own (for the function calls) and at the same time a
    {  "AEWF"    ,         t_File::AEWF         }, // subformat of EWF (for the user interface). Looks a bit strange at first sight, but
@@ -351,14 +352,16 @@ static t_ToolCfgSet SetArrDeviceScanMethod[] =
 {
    // Name in cfg file  Corresponding value
    // ----------------------------------------
-   { "LibParted",       SCANMETHOD_LIBPARTED },
-   { "Parted",          SCANMETHOD_LIBPARTED },
+   { "libparted",       SCANMETHOD_LIBPARTED },
+   { "parted",          SCANMETHOD_LIBPARTED },
    { "DBusHAL",         SCANMETHOD_DBUSHAL   },
    { "HAL",             SCANMETHOD_DBUSHAL   },
    { "DBusDevKit",      SCANMETHOD_DBUSDEVKIT},
    { "DevKit",          SCANMETHOD_DBUSDEVKIT},
    { "DBusUDisks",      SCANMETHOD_DBUSDEVKIT},
    { "UDisks",          SCANMETHOD_DBUSDEVKIT},
+   { "libudev",         SCANMETHOD_LIBUDEV   },
+   { "udev",            SCANMETHOD_LIBUDEV   },
    {  NULL,             0                    }
 };
 
@@ -423,7 +426,12 @@ static t_ToolCfgParamDesc CfgParamDescArr[] =
    {CFGASSIGN_BOTH_MULTIPLE, NULL       , {"SpecialFilenameChars"          , CFGTYPE_STRING , ELT_SIZ(SpecialFilenameChars)      ,                         0,       0, NULL                            }, CFG_FILLUP_FORLINT},
    {CFGASSIGN_BOTH_MULTIPLE, NULL       , {"CalcImageFileMD5"              , CFGTYPE_SET    , ELT(CalcImageFileMD5)              ,                0,       0,       0, INIARR(SetArrBoolean)           }, CFG_FILLUP_FORLINT},
    {CFGASSIGN_BOTH_MULTIPLE, NULL       , {"DuplicateImage"                , CFGTYPE_SET    , ELT(DuplicateImage)                ,                0,       0,       0, INIARR(SetArrBoolean)           }, CFG_FILLUP_FORLINT},
+   {CFGASSIGN_BOTH_MULTIPLE, NULL       , {"DirectoryFieldEditing"         , CFGTYPE_SET    , ELT(DirectoryFieldEditing)         ,                0,       0,       0, INIARR(SetArrBoolean)           }, CFG_FILLUP_FORLINT},
+   {CFGASSIGN_BOTH_MULTIPLE, NULL       , {"AllowPathInFilename"           , CFGTYPE_SET    , ELT(AllowPathInFilename)           ,                0,       0,       0, INIARR(SetArrBoolean)           }, CFG_FILLUP_FORLINT},
+   {CFGASSIGN_BOTH_MULTIPLE, NULL       , {"ConfirmDirectoryCreation"      , CFGTYPE_SET    , ELT(ConfirmDirectoryCreation)      ,                0,       0,       0, INIARR(SetArrBoolean)           }, CFG_FILLUP_FORLINT},
+
    {CFGASSIGN_BOTH_MULTIPLE, NULL       , {"AvoidEncaseProblems"           , CFGTYPE_SET    , ELT(AvoidEncaseProblems)           ,                0,       0,       0, INIARR(SetArrBoolean)           }, CFG_FILLUP_FORLINT},
+   {CFGASSIGN_BOTH_MULTIPLE, NULL       , {"AvoidCifsProblems"             , CFGTYPE_SET    , ELT(AvoidCifsProblems)             ,                0,       0,       0, INIARR(SetArrBoolean)           }, CFG_FILLUP_FORLINT},
 
    {CFGASSIGN_BOTH_MULTIPLE, NULL       , {"DeviceScanMethod"              , CFGTYPE_SET    , ELT(DeviceScanMethod)              ,                0,       0,       0, INIARR(SetArrDeviceScanMethod)  }, CFG_FILLUP_FORLINT},
    {CFGASSIGN_BOTH_MULTIPLE, NULL       , {"ScanInterval"                  , CFGTYPE_INTEGER, ELT(ScanInterval                  ),                0,       1, 8640000, NULL                            }, CFG_FILLUP_FORLINT},
