@@ -9,22 +9,22 @@
 //  Module:         Application configuration data
 // ****************************************************************************
 
-// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014 Guy Voncken
+// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016 Guy Voncken
 //
-// This file is part of guymager.
+// This file is part of Guymager.
 //
-// guymager is free software: you can redistribute it and/or modify
+// Guymager is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation, either version 2 of the License, or
 // (at your option) any later version.
 //
-// guymager is distributed in the hope that it will be useful,
+// Guymager is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with guymager. If not, see <http://www.gnu.org/licenses/>.
+// along with Guymager. If not, see <http://www.gnu.org/licenses/>.
 
 #ifndef __CONFIG_H__
 #define __CONFIG_H__
@@ -110,6 +110,7 @@ typedef enum
    SCANMETHOD_LIBPARTED=0,
    SCANMETHOD_DBUSHAL,
    SCANMETHOD_DBUSDEVKIT,
+   SCANMETHOD_LIBUDEV,
 
    SCANMETHOD_COUNT
 } t_CfgScanMethod;
@@ -180,7 +181,11 @@ typedef struct
    char                 SpecialFilenameChars[CFG_MAX_MISC_LEN+1];
    int                  CalcImageFileMD5;
    int                  DuplicateImage;
+   int                  DirectoryFieldEditing;
+   int                  AllowPathInFilename;
+   int                  ConfirmDirectoryCreation;
    int                  AvoidEncaseProblems;
+   int                  AvoidCifsProblems;
 
    int                  FifoBlockSizeDD;
    int                  FifoBlockSizeEWF;
