@@ -11,25 +11,30 @@
 //                  window.
 // ****************************************************************************
 
-// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014 Guy Voncken
+// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016 Guy Voncken
 //
-// This file is part of guymager.
+// This file is part of Guymager.
 //
-// guymager is free software: you can redistribute it and/or modify
+// Guymager is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation, either version 2 of the License, or
 // (at your option) any later version.
 //
-// guymager is distributed in the hope that it will be useful,
+// Guymager is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with guymager. If not, see <http://www.gnu.org/licenses/>.
+// along with Guymager. If not, see <http://www.gnu.org/licenses/>.
 
 #include <float.h>
 
+#if (QT_VERSION >= 0x050000)
+   #include <QtWidgets> //lint !e537 Repeated include
+#else
+   #include <QtGui>     //lint !e537 Repeated include
+#endif
 #include <QString>
 #include <QList>
 
@@ -844,8 +849,8 @@ void t_Device::ProcessTokenString (QString &Str, t_pDevice pDevice)
 
       DeviceReplace (Str, "%dev%"            , pDevice->LinuxDevice );
       DeviceReplace (Str, "%Size%"           , pDevice->Size        );
-      DeviceReplace (Str, "%SizeHuman%"      , GetSizeHumanFrac (pDevice, true, 0, 10000).toString());
-      DeviceReplace (Str, "%SizeHumanNoSep%" , GetSizeHumanFrac (pDevice, true, 0, 10000).toString(), true);
+      DeviceReplace (Str, "%SizeHuman%"      , GetSizeHumanFrac (pDevice, true, 0, 10000, false).toString());
+      DeviceReplace (Str, "%SizeHumanNoSep%" , GetSizeHumanFrac (pDevice, true, 0, 10000, true ).toString());
       DeviceReplace (Str, "%State%"          , QString(pDevice->StateStr()));
       DeviceReplace (Str, "%Serial%"         , pDevice->SerialNumber);
       DeviceReplace (Str, "%Model%"          , pDevice->Model       );
