@@ -9,23 +9,24 @@
 //  Module:         Dialog that is opened when aborting an acquisition
 // ****************************************************************************
 
-// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014 Guy Voncken
+// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016 Guy Voncken
 //
-// This file is part of guymager.
+// This file is part of Guymager.
 //
-// guymager is free software: you can redistribute it and/or modify
+// Guymager is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation, either version 2 of the License, or
 // (at your option) any later version.
 //
-// guymager is distributed in the hope that it will be useful,
+// Guymager is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with guymager. If not, see <http://www.gnu.org/licenses/>.
+// along with Guymager. If not, see <http://www.gnu.org/licenses/>.
 
+#include "common.h"
 
 #include "dlgabort.h"
 #include "config.h"
@@ -51,7 +52,7 @@ t_DlgAbort::t_DlgAbort (void)
    CHK_EXIT (ERROR_DLGABORT_CONSTRUCTOR_NOT_SUPPORTED)
 } //lint !e1401 pOwn not initialised
 
-t_DlgAbort::t_DlgAbort (t_pcDevice pDevice, QWidget *pParent, Qt::WFlags Flags)
+t_DlgAbort::t_DlgAbort (t_pcDevice pDevice, QWidget *pParent, Qt::WindowFlags Flags)
    :QDialog (pParent, Flags)
 {
    static bool Initialised = false;
