@@ -9,26 +9,29 @@
 //  Module:         Acquisition dialog
 // ****************************************************************************
 
-// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014 Guy Voncken
+// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016 Guy Voncken
 //
-// This file is part of guymager.
+// This file is part of Guymager.
 //
-// guymager is free software: you can redistribute it and/or modify
+// Guymager is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation, either version 2 of the License, or
 // (at your option) any later version.
 //
-// guymager is distributed in the hope that it will be useful,
+// Guymager is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with guymager. If not, see <http://www.gnu.org/licenses/>.
+// along with Guymager. If not, see <http://www.gnu.org/licenses/>.
 
-#include <QtGui>
+#if (QT_VERSION >= 0x050000)
+   #include <QtWidgets> //lint !e537 Repeated include
+#else
+   #include <QtGui>     //lint !e537 Repeated include
+#endif
 #include <QDesktopWidget>
-#include <QX11Info>
 
 #include "toolconstants.h"
 
@@ -65,9 +68,9 @@ class t_DlgAcquireLocal
       QRadioButton    *pRadioButtonFormatEWF;
       QRadioButton    *pRadioButtonFormatAFF;
 
-      QList<QWidget*>   EwfWidgetsList;                  // Used to comfortably enable / disable EWF related entry fields and labels
+      QList<QWidget*>   EwfWidgetsList;      // Used to comfortably enable / disable EWF related entry fields and labels
 
-      QTableWidget    *pDeviceTable;                     // Only created and displayed when cloning a device
+      QTableWidget    *pDeviceTable;         // Only created and displayed when cloning a device
 
       QPushButton     *pButtonOk;
       QPushButton     *pButtonDuplicate;
@@ -75,9 +78,12 @@ class t_DlgAcquireLocal
       QPushButton     *pButtonCancel;
 
       t_pDevice        pDevice;
+      t_pDeviceList    pDeviceList;
+      t_pAcquisition   pAcquisition1;        // Contains the values entered in the first acquisition dialog in case this dialog is the duplicate dialog. Used
+                                             // for checking consistency of values entered in both acquisition dialogs (cross check info and image filenames)
 
-      bool              OldSplitFileSwitch;              // Required to remember SplitFileSwitch when chaging forth and back
-                                                         // between formats that support split files and not.
+      bool              OldSplitFileSwitch;  // Required to remember SplitFileSwitch when chaging forth and back
+                                             // between formats that support split files and not.
 };
 
 
@@ -259,9 +265,8 @@ APIRET t_DlgAcquire::AddField (t_pDevice pDevice, t_pCfgDlgAcquireField pField,
    QComboBox             *pComboBox     = NULL;
    QLabel                *pLabel        = NULL;
    QWidget               *pEntryWidget  = NULL;
-   QPushButton           *pButtonBrowse = NULL;
+   QToolButton           *pButtonBrowse = NULL;
    QString                 Set;
-   QSize                   MinButtonSize;
    bool                    Ok;
 
    // Create field
@@ -282,8 +287,13 @@ APIRET t_DlgAcquire::AddField (t_pDevice pDevice, t_pCfgDlgAcquireField pField,
    }
 
    if ((pField->DirField) && (EntryMode(pField) != CFG_ENTRYMODE_HIDE))
-      pButtonBrowse = new QPushButton (tr("...", "The directory browse button"), this);
-
+   {
+      pButtonBrowse = new QToolButton (this);
+      QSize MaximumSize = pButtonBrowse->maximumSize();
+      MaximumSize.setWidth (USHRT_MAX);
+      pButtonBrowse->setMaximumSize (MaximumSize);
+      pButtonBrowse->setText (tr("...", "The directory browse button"));
+   }
    // Position field
    // --------------
    pField->pLineEdit = pLineEdit;
@@ -309,10 +319,6 @@ APIRET t_DlgAcquire::AddField (t_pDevice pDevice, t_pCfgDlgAcquireField pField,
          {
             pLayout->addWidget (pLabel       , *pRow, 0);
             pLayout->addWidget (pButtonBrowse, *pRow, 1);
-            MinButtonSize = pButtonBrowse->minimumSize();
-            MinButtonSize.setWidth(20);
-            pButtonBrowse->setSizePolicy (QSizePolicy(QSizePolicy::Ignored, QSizePolicy::Preferred));   // Allow to shrink horizontal size below preferred minimum
-            pButtonBrowse->setMinimumSize(MinButtonSize);
          }
          else if (pLabel)
          {
@@ -358,7 +364,8 @@ APIRET t_DlgAcquire::AddField (t_pDevice pDevice, t_pCfgDlgAcquireField pField,
    CHK_EXIT (DlgAcquireGetFieldValue (pDevice, pOwn->Clone, pField, ForceLastEnteredValues, Set))
    if (pField->DirField)
    {
-      pLineEdit->setReadOnly (true);
+      if (!CONFIG(DirectoryFieldEditing))
+         pLineEdit->setReadOnly (true);
       if (!Set.endsWith ("/"))
          Set += "/";
    }
@@ -450,8 +457,8 @@ APIRET t_DlgAcquire::InsertDeviceTableRow (QTableWidget *pTable, int Row, t_pDev
    else if (pDevDst       == pDevSrc)                     Remark = tr("Device to be cloned");
    else if (pDevDst->Size <  pDevSrc->Size)               Remark = tr("Too small");
    else if (InUse)                                        Remark = tr("In use");
-   else if (pOwn->Duplicate && ((pDevSrc->Acquisition1.ImagePath +
-                                 pDevSrc->Acquisition1.ImageFilename) == pDevDst->LinuxDevice))
+   else if (pOwn->Duplicate && ((pOwn->pAcquisition1->ImagePath +
+                                 pOwn->pAcquisition1->ImageFilename) == pDevDst->LinuxDevice))
                                                           Remark = tr("Selected for first acquisition");
    else if (pDeviceList->UsedAsCloneDestination(pDevDst)) Remark = tr("Used in another clone operation");
    else                                                 { Remark = tr("Ok for cloning"); Selectable = true;}
@@ -574,7 +581,7 @@ class t_DlgAcquireLayoutScroller: public QScrollArea // This class makes layouts
 
 
 // t_DlgAcquire::t_DlgAcquire: Duplicate is false for the 1st acquisition dialog and true for the 2nd one.
-t_DlgAcquire::t_DlgAcquire (t_pDevice pDevice, bool Clone, t_pDeviceList pDeviceList, bool Duplicate, QWidget *pParent, Qt::WFlags Flags, bool ForceLastEnteredValues)
+t_DlgAcquire::t_DlgAcquire (t_pDevice pDevice, bool Clone, t_pDeviceList pDeviceList, bool Duplicate, QWidget *pParent, Qt::WindowFlags Flags, bool ForceLastEnteredValues, t_pAcquisition pAcquisition1)
    :QDialog (pParent, Flags)
 {
    static bool                  Initialised = false;
@@ -616,10 +623,12 @@ t_DlgAcquire::t_DlgAcquire (t_pDevice pDevice, bool Clone, t_pDeviceList pDevice
    else  /*( Duplicate &&  Clone) */  setWindowTitle (tr ("Duplicate Clone %1"   , "Dialog title, %1 is the device (for instance /dev/hdc)") .arg(pDevice->LinuxDevice));
 
    pOwn    = new t_DlgAcquireLocal;
-   pOwn->pDevice      = pDevice;
-   pOwn->Clone        = Clone;
-   pOwn->pDeviceTable = NULL;
-   pOwn->Duplicate    = Duplicate;
+   pOwn->pDevice       = pDevice;
+   pOwn->Clone         = Clone;
+   pOwn->pDeviceTable  = NULL;
+   pOwn->Duplicate     = Duplicate;
+   pOwn->pAcquisition1 = pAcquisition1;
+   pOwn->pDeviceList   = pDeviceList;
 
    // Organisation of the whole dialog
    //     Dialog
@@ -738,7 +747,6 @@ t_DlgAcquire::t_DlgAcquire (t_pDevice pDevice, bool Clone, t_pDeviceList pDevice
 
    // Destination box
    // ---------------
-
    QGroupBox   *pGroupBoxDest = new QGroupBox(tr("Destination"), this);
    QGridLayout *pLayoutDest   = new QGridLayout ();
    pGroupBoxDest->setLayout (pLayoutDest);
@@ -859,7 +867,10 @@ t_DlgAcquire::t_DlgAcquire (t_pDevice pDevice, bool Clone, t_pDeviceList pDevice
 
    if (DialogRect.height() < sizeHint().height())
    {
-      QRect ScreenRect = QApplication::desktop()->screenGeometry(x11Info().screen());
+      QDesktopWidget *pDesktop;
+
+      pDesktop = QApplication::desktop();
+      QRect ScreenRect = pDesktop->screenGeometry(pDesktop->screenNumber(this));
       int   NewHeight  = GETMIN (ScreenRect.height()*0.9, sizeHint().height());
 
       DialogRect.setX      ((ScreenRect.width () - DialogRect.width())/2);
@@ -1111,11 +1122,13 @@ static APIRET DlgAcquireCheckFilename (const QString &In, bool &Clean, QString &
    Out   = "";
    for (i=0; i<In.length(); i++)
    {
-      Ch = In[i].toAscii();
-      Ok = ((Ch >= '0') && (Ch <= '9')) ||
-           ((Ch >= 'a') && (Ch <= 'z')) ||
-           ((Ch >= 'A') && (Ch <= 'Z')) ||
-            (Ch == '_') || SpecialChars.contains(Ch);
+      Ch = In[i].toLatin1();
+      Ok = ((Ch >= '0') && (Ch <= '9'))                 ||
+           ((Ch >= 'a') && (Ch <= 'z'))                 ||
+           ((Ch >= 'A') && (Ch <= 'Z'))                 ||
+            (Ch == '_')                                 ||
+           ((Ch == '/') && CONFIG(AllowPathInFilename)) ||
+           SpecialChars.contains(Ch);
       if (Ok)
            Out += Ch;
       else Clean = false;
@@ -1126,15 +1139,43 @@ static APIRET DlgAcquireCheckFilename (const QString &In, bool &Clean, QString &
    return NO_ERROR;
 }
 
+// AdjustPathAndFilename analyses Path and Filename and separates/reassembles them correctly. This
+// function became neccessary with the introduction of relative paths in the filename field (configuration
+// parameter AllowPathInFilename)
+// Example:   input - Path     = /home             |     output - Path     = /home/vogu/aa/
+//                    Filename = vogu/aa/test      |              Filename = test
+//
+
+APIRET t_DlgAcquire::AdjustPathAndFilename (QString &Path, QString &Filename)
+{
+   int LastSlash;
+
+   if (!Path.endsWith ('/'))
+      Path += '/';
+
+   if (Filename.startsWith ('/'))
+      Filename.remove (0,1);
+
+   LastSlash = Filename.lastIndexOf ('/');
+   if (LastSlash >= 0)
+   {
+       Path += Filename.left (LastSlash+1);
+       Filename.remove (0, LastSlash+1);
+   }
+   return NO_ERROR;
+}
 
 APIRET t_DlgAcquire::CheckWriteAccess (t_pcDevice pDevice, const QString &Path, const QString &Filename, bool &Ok)
 {
    FILE       *pFile;
    const char *pStr = "Test file created by Guymager for checking write access.\r\nYou may delete this file";
    const int    StrLen = strlen (pStr);
-   QString      TestFileName = Path + Filename + ".test";
+   QString      TestFileName;
    int          wr;
    bool         DirOk;
+   QMessageBox::StandardButton  Button;
+
+   TestFileName = Path + Filename + ".test";
 
    // Create directory if it doesn't exist
    // ------------------------------------
@@ -1146,8 +1187,23 @@ APIRET t_DlgAcquire::CheckWriteAccess (t_pcDevice pDevice, const QString &Path,
    }
    else
    {
-      LOG_INFO ("[%s] Directory %s doesn't exist, trying to create it", QSTR_TO_PSZ(pDevice->LinuxDevice), QSTR_TO_PSZ(Path))
-      DirOk = Dir.mkpath(Path);
+      if (CONFIG(ConfirmDirectoryCreation))
+      {
+         LOG_INFO ("[%s] Directory %s doesn't exist. Asking user if it should be created.", QSTR_TO_PSZ(pDevice->LinuxDevice), QSTR_TO_PSZ(Path))
+         Button = t_MessageBox::question (this, tr ("Path not found", "Dialog title"),
+                                                tr ("The destination directory"
+                                                    "\n   %1"
+                                                    "\ndoesn't exist. Do you want to create it?") .arg(Path), QMessageBox::Yes | QMessageBox::No, QMessageBox::No);
+         Ok = Button == QMessageBox::Yes;
+         if (!Ok)
+         {
+            LOG_INFO ("[%s] User cancels directory creation", QSTR_TO_PSZ(pDevice->LinuxDevice))
+            return NO_ERROR;
+         }
+         LOG_INFO ("[%s] User agrees to create directory", QSTR_TO_PSZ(pDevice->LinuxDevice))
+      }
+      LOG_INFO ("[%s] Creating directory %s.", QSTR_TO_PSZ(pDevice->LinuxDevice), QSTR_TO_PSZ(Path))
+      DirOk = Dir.mkpath(Path); // Corresponds to mkdir -p
       if (DirOk)
          DirOk = Dir.exists();
 
@@ -1203,8 +1259,8 @@ APIRET t_DlgAcquire::CheckWriteAccess (t_pcDevice pDevice, const QString &Path,
 }
 
 static QString DlgAcquireCanonicalPath (const QString &Path, const QString &Filename)
-{                                                        // Do not use QFileInfo::canonicalFilePath, as it returns an empty for non-existent files. As well,
-   return QDir(Path).canonicalPath() + "/" + Filename;   // QDir::canonicalPath returns an empty for non-existent dirs if doesn't exist, see remakrs below where
+{                                                        // Do not use QFileInfo::canonicalFilePath, as it returns an empty string for non-existent files. As well,
+   return QDir(Path).canonicalPath() + "/" + Filename;   // QDir::canonicalPath returns an empty string for non-existent dirs if doesn't exist, see remarks below where
 }                                                        // this fn is used.
 
 void t_DlgAcquire::SlotOk        (void) { Accept (false); }
@@ -1215,14 +1271,12 @@ void t_DlgAcquire::SlotCancel    (void) { done (t_DlgAcquire::ButtonCancel); }
 void t_DlgAcquire::Accept (bool DuplicatePressed)
 {
    t_Acquisition                Acquisition (NULL);
-   t_pDlgAcquireLineEdit       pLineEditDestImageFilename;
-   t_pDlgAcquireLineEdit       pLineEditDestInfoFilename;
-   QMessageBox::StandardButton  Button;
-   QString                      ImageFilenameCorrected;
-   QString                      InfoFilenameCorrected;
+   t_pDevice                   pDevice;
+   t_pDlgAcquireLineEdit       pLineEditImageDirectory         , pLineEditImageFilename         , pLineEditInfoDirectory         , pLineEditInfoFilename;
+   QString                              ImageDirectoryCorrected,          ImageFilenameCorrected,          InfoDirectoryCorrected,          InfoFilenameCorrected;
+   bool                                 ImageDirectoryClean    ,          ImageFilenameClean    ,          InfoDirectoryClean    ,          InfoFilenameClean;
    QString                      Message;
-   bool                         ImageFilenameClean;
-   bool                         InfoFilenameClean;
+   QMessageBox::StandardButton  Button;
    unsigned long long           SplitSize = 0;
 
    LOG_INFO ("[%s] Acquisition dialog accept - %s pressed", QSTR_TO_PSZ(pOwn->pDevice->LinuxDevice), DuplicatePressed ? "Duplicate" : "Ok")
@@ -1280,60 +1334,67 @@ void t_DlgAcquire::Accept (bool DuplicatePressed)
       }
    }
 
-   // Check for strange characters in filenames
-   // -----------------------------------------
-   pLineEditDestImageFilename = DlgAcquireGetField (CFG_DLGACQUIRE_DEST_IMAGEFILENAME)->pLineEdit;
-   pLineEditDestInfoFilename  = DlgAcquireGetField (CFG_DLGACQUIRE_DEST_INFOFILENAME )->pLineEdit;
+   // Check for strange characters in directories and filenames
+   // ---------------------------------------------------------
+   pLineEditImageDirectory = DlgAcquireGetField (CFG_DLGACQUIRE_DEST_IMAGEDIRECTORY)->pLineEdit;
+   pLineEditImageFilename  = DlgAcquireGetField (CFG_DLGACQUIRE_DEST_IMAGEFILENAME )->pLineEdit;
+   pLineEditInfoDirectory  = DlgAcquireGetField (CFG_DLGACQUIRE_DEST_INFODIRECTORY )->pLineEdit;
+   pLineEditInfoFilename   = DlgAcquireGetField (CFG_DLGACQUIRE_DEST_INFOFILENAME  )->pLineEdit;
+
+   CHK_EXIT (DlgAcquireCheckFilename (pLineEditImageDirectory->text(), ImageDirectoryClean, ImageDirectoryCorrected))  // Check all image/info directories and
+   CHK_EXIT (DlgAcquireCheckFilename (pLineEditImageFilename ->text(), ImageFilenameClean , ImageFilenameCorrected ))  // filenames and then override those that
+   CHK_EXIT (DlgAcquireCheckFilename (pLineEditInfoDirectory ->text(), InfoDirectoryClean , InfoDirectoryCorrected ))  // should not be checked (it's easier to do
+   CHK_EXIT (DlgAcquireCheckFilename (pLineEditInfoFilename  ->text(), InfoFilenameClean  , InfoFilenameCorrected  ))  // it that way then with a lot of if/else)
 
    if (pOwn->Clone)
    {
-      ImageFilenameClean     = true;
-      ImageFilenameCorrected = pLineEditDestImageFilename->text();
+      ImageDirectoryClean = true;
+      ImageFilenameClean  = true;
    }
-   else
-   {
-      CHK_EXIT (DlgAcquireCheckFilename (pLineEditDestImageFilename->text(), ImageFilenameClean, ImageFilenameCorrected))
+   if (!CONFIG (DirectoryFieldEditing))  // Directories selected via file dialog are always good and must
+   {                                     // not be checked/replaced (check would like to replace slashes)
+      ImageDirectoryClean = true;
+      InfoDirectoryClean  = true;
    }
-   CHK_EXIT (DlgAcquireCheckFilename (pLineEditDestInfoFilename->text(), InfoFilenameClean, InfoFilenameCorrected))
 
-   if (!ImageFilenameClean || !InfoFilenameClean)
+   if (!ImageDirectoryClean || !ImageFilenameClean || !InfoDirectoryClean || !InfoFilenameClean)
    {
-      LOG_INFO ("Unallowed characters in filenames found")
-      if (pOwn->Clone)
-           Message = tr ("The info filename contains special characters which are not allowed. Guymager suggests the following changes:"
-                         "\n\t%1"
-                         "\nDo you accept these changes?") .arg(InfoFilenameCorrected);
-      else Message = tr ("The filenames contain special characters which are not allowed. Guymager suggests the following changes:"
-                         "\n\tImage filename: %1"
-                         "\n\tInfo filename: %2"
-                         "\nDo you accept these changes?") .arg(ImageFilenameCorrected) .arg(InfoFilenameCorrected);
+      LOG_INFO ("[%s] Unallowed characters in filenames or directories found", QSTR_TO_PSZ(pOwn->pDevice->LinuxDevice))
+      Message = tr ("The directory or file names contain special characters which are not allowed. Guymager suggests the following changes:");
+      if (!ImageDirectoryClean)                                                                       Message += tr ("\n   Image directory:\t%1") .arg (ImageDirectoryCorrected);
+      if (!ImageFilenameClean )                                                                       Message += tr ("\n   Image filename:\t%1" ) .arg (ImageFilenameCorrected );
+      if (!InfoDirectoryClean && (pLineEditInfoDirectory->text() != pLineEditImageDirectory->text())) Message += tr ("\n   Info directory:\t%1" ) .arg (InfoDirectoryCorrected );
+      if (!InfoFilenameClean  && (pLineEditInfoFilename ->text() != pLineEditImageFilename ->text())) Message += tr ("\n   Info filename:\t%1"  ) .arg (InfoFilenameCorrected  );
 
+      Message += tr ("\nDo you accept these changes?");
       Button = t_MessageBox::question (this, tr ("Special characters", "Dialog title"), Message, QMessageBox::Yes | QMessageBox::No, QMessageBox::Yes);
       if (Button == QMessageBox::Yes)
       {
-         LOG_INFO ("User accepts filename changes")
-         pLineEditDestImageFilename->setText(ImageFilenameCorrected);
-         pLineEditDestInfoFilename ->setText(InfoFilenameCorrected );
+         LOG_INFO ("[%s] User accepts filename changes", QSTR_TO_PSZ(pOwn->pDevice->LinuxDevice))
+         if (!ImageDirectoryClean) pLineEditImageDirectory->setText (ImageDirectoryCorrected);
+         if (!ImageFilenameClean ) pLineEditImageFilename ->setText (ImageFilenameCorrected );
+         if (!InfoDirectoryClean ) pLineEditInfoDirectory ->setText (InfoDirectoryCorrected );
+         if (!InfoFilenameClean  ) pLineEditInfoFilename  ->setText (InfoFilenameCorrected  );
       }
       else
       {
-         LOG_INFO ("User rejects filename changes")
+         LOG_INFO ("[%s] User rejects filename changes", QSTR_TO_PSZ(pOwn->pDevice->LinuxDevice))
          return;
       }
    }
 
-   // Check if duplicate image name is identical to first image name
-   // --------------------------------------------------------------
+   // Check if duplicate image or info filename is identical to image name of first acquisition
+   // ------------------------------------------------------------------------------------------
    CHK_EXIT (GetParameters (Acquisition, false))
 
-   if (pOwn->Duplicate)
+   if (pOwn->Duplicate && pOwn->pAcquisition1) // Both conditions normally are always both true or both false, but let's check both here just to be sure
    {
-      QString ImageFilename1 = DlgAcquireCanonicalPath (pOwn->pDevice->Acquisition1.ImagePath, pOwn->pDevice->Acquisition1.ImageFilename);
-      QString InfoFilename1  = DlgAcquireCanonicalPath (pOwn->pDevice->Acquisition1.ImagePath, pOwn->pDevice->Acquisition1.InfoFilename );
+      QString ImageFilename1 = DlgAcquireCanonicalPath (pOwn->pAcquisition1->ImagePath, pOwn->pAcquisition1->ImageFilename);
+      QString InfoFilename1  = DlgAcquireCanonicalPath (pOwn->pAcquisition1->ImagePath, pOwn->pAcquisition1->InfoFilename );
       QString ImageFilename2 = DlgAcquireCanonicalPath (Acquisition.ImagePath, Acquisition.ImageFilename);
       QString InfoFilename2  = DlgAcquireCanonicalPath (Acquisition.ImagePath, Acquisition.InfoFilename );
-      // DlgAcquireCanonicalPath only returns the filename if the path doesn't exist. As the path of Acquisition1 surely exists (created
-      // by t_DlgAcquire::CheckWriteAccess during the 1st acquisition dialog if it wasn't there yet), the string comparison following
+      // DlgAcquireCanonicalPath only returns the filename if the path doesn't exist (see above). As the path of Acquisition1 surely exists
+      // (created by t_DlgAcquire::CheckWriteAccess during the 1st acquisition dialog if it wasn't there yet), the string comparison following
       // below returns a correct result even if the user chosed a non-existent path for the duplicate acquisition.
 
       if (ImageFilename1.toUpper() == ImageFilename2.toUpper())
@@ -1359,12 +1420,53 @@ void t_DlgAcquire::Accept (bool DuplicatePressed)
    if (!pOwn->Clone)
    {
       CHK_EXIT (t_DlgAcquire::CheckWriteAccess (pOwn->pDevice, Acquisition.InfoPath, Acquisition.InfoFilename, Ok))
-      if (Ok && (Acquisition.InfoPath != Acquisition.ImagePath))
+      if (Ok && ((Acquisition.InfoPath     != Acquisition.ImagePath    ) ||
+                 (Acquisition.InfoFilename != Acquisition.ImageFilename)))
          CHK_EXIT (t_DlgAcquire::CheckWriteAccess (pOwn->pDevice, Acquisition.ImagePath, Acquisition.ImageFilename, Ok))
       if (!Ok)
          return;
    }
 
+   // Check if another acquisition uses the same image or info files
+   // --------------------------------------------------------------
+   bool Used=false;
+   #define CHK_PATH(Path1,File1,Path2,File2)           \
+   {                                                   \
+      Used = DlgAcquireCanonicalPath (Path1, File1) == \
+             DlgAcquireCanonicalPath (Path2, File2);   \
+      if (Used)                                        \
+         break;                                        \
+   }
+
+   for (int i=0; i<pOwn->pDeviceList->count(); i++)
+   {
+      pDevice = pOwn->pDeviceList->at(i);
+
+      if (pDevice == pOwn->pDevice)                      // Do not check the device that user wants to acquire
+         continue;
+      if ((pDevice->GetState() == t_Device::Idle   ) ||
+          (pDevice->GetState() == t_Device::Aborted))    // Files from an aborted acquisition can be overwritten
+         continue;
+      CHK_PATH (pDevice->Acquisition1.ImagePath, pDevice->Acquisition1.ImageFilename, Acquisition.ImagePath, Acquisition.ImageFilename);
+      CHK_PATH (pDevice->Acquisition1.InfoPath , pDevice->Acquisition1.InfoFilename , Acquisition.InfoPath , Acquisition.InfoFilename );
+      if (pDevice->Duplicate)
+      {
+         CHK_PATH (pDevice->Acquisition2.ImagePath, pDevice->Acquisition2.ImageFilename, Acquisition.ImagePath, Acquisition.ImageFilename);
+         CHK_PATH (pDevice->Acquisition2.InfoPath , pDevice->Acquisition2.InfoFilename , Acquisition.InfoPath , Acquisition.InfoFilename );
+      }
+   }
+   if (Used)
+   {
+      LOG_INFO ("[%s] Another acquisition (%s) is using the same file names", QSTR_TO_PSZ(pOwn->pDevice->LinuxDevice),
+                                                                              QSTR_TO_PSZ(pDevice->LinuxDevice))
+      Button = t_MessageBox::warning (this, tr ("Files already used", "Dialog title"),
+                                                tr ("The image or info files already are used in the acquisition of %1. Please chose different ones.") .arg(pDevice->LinuxDevice),
+                                                QMessageBox::Ok);
+      LOG_INFO ("[%s] User closes info dialog", QSTR_TO_PSZ(pOwn->pDevice->LinuxDevice))
+      return;
+   }
+   #undef CHK_PATH
+
    // Check if image file already exists
    // ----------------------------------
 
@@ -1376,17 +1478,17 @@ void t_DlgAcquire::Accept (bool DuplicatePressed)
 
    if (pOwn->Clone)
    {
-      Empty = true;
+      Empty = true;  // No image file when cloning drives, so no check
    }
    else
-   {
+   {                 // Check if image file with name/extension already exists
       DdSplitDecimals = t_File::GetDdSplitNrDecimals (pOwn->pDevice->Size, Acquisition.SplitFileSize);
       CHK_EXIT (t_File::GetFormatExtension (Acquisition.Format, Acquisition.Clone, DdSplitDecimals, &ExtensionImage))
       NameFilter = Acquisition.ImageFilename + ExtensionImage;
       Empty = Dir.entryInfoList (QStringList(NameFilter), QDir::Files, QDir::Name).isEmpty();
    }
    if (Empty)
-   {
+   {                 // Check if info file already exists
       Dir.setPath (Acquisition.InfoPath);
       NameFilter = Acquisition.InfoFilename + t_File::pExtensionInfo;
       Empty = Dir.entryInfoList (QStringList(NameFilter), QDir::Files, QDir::Name).isEmpty();
@@ -1394,18 +1496,18 @@ void t_DlgAcquire::Accept (bool DuplicatePressed)
 
    if (!Empty)
    {
-      LOG_INFO ("Image file / info files already exist")
+      LOG_INFO ("[%s] Image file / info files already exist", QSTR_TO_PSZ(pOwn->pDevice->LinuxDevice))
       Button = t_MessageBox::question (this, tr ("Files exist", "Dialog title"),
                                        pOwn->Clone ? tr ("The info file already exists. Do you want to overwrite it?") :
                                                      tr ("The image or info files already exist. Do you want to overwrite them?"),
                                        QMessageBox::Yes | QMessageBox::No, QMessageBox::No);
       if (Button == QMessageBox::Yes)
       {
-         LOG_INFO ("User accepts to overwrite existing image/info files")
+         LOG_INFO ("[%s] User accepts to overwrite existing image/info files", QSTR_TO_PSZ(pOwn->pDevice->LinuxDevice))
       }
       else
       {
-         LOG_INFO ("User rejects to overwrite existing image/info files")
+         LOG_INFO ("[%s] User rejects to overwrite existing image/info files", QSTR_TO_PSZ(pOwn->pDevice->LinuxDevice))
          return;
       }
    }
@@ -1421,7 +1523,7 @@ void t_DlgAcquire::Accept (bool DuplicatePressed)
 
       if (Segments > 14971)  // (E01-E99)->99 + (EAA-EZZ)->26*26 + (FAA-ZZZ) -> 26*26*21 = 14.971
       {
-         LOG_INFO ("This image could include up to %llu segment files (beyond extension ZZZ)", Segments)
+         LOG_INFO ("[%s] This image could include up to %llu segment files (beyond extension ZZZ)", QSTR_TO_PSZ(pOwn->pDevice->LinuxDevice), Segments)
          Button = t_MessageBox::question (this, tr ("Large amount of segment files", "Dialog title"),
                                           tr ("With the chosen segment size, up to %1 image segment files could possibly be created. "
                                               "This would result in file extensions beyond .ZZZ"
@@ -1429,11 +1531,11 @@ void t_DlgAcquire::Accept (bool DuplicatePressed)
                                           QMessageBox::Yes | QMessageBox::No, QMessageBox::No);
          if (Button == QMessageBox::Yes)
          {
-            LOG_INFO ("User accepts large amount of segment files")
+            LOG_INFO ("[%s] User accepts large amount of segment files", QSTR_TO_PSZ(pOwn->pDevice->LinuxDevice))
          }
          else
          {
-            LOG_INFO ("User refuses large amount of segment files")
+            LOG_INFO ("[%s] User refuses large amount of segment files", QSTR_TO_PSZ(pOwn->pDevice->LinuxDevice))
             return;
          }
       }
@@ -1551,6 +1653,8 @@ APIRET t_DlgAcquire::GetParameters (t_Acquisition &Acquisition, bool RememberLas
    COPY_LINEENTRY (Acquisition.ImageFilename , CFG_DLGACQUIRE_DEST_IMAGEFILENAME , pOwn->Clone ? false : RememberLastUsedValues)
    COPY_LINEENTRY (Acquisition.InfoPath      , CFG_DLGACQUIRE_DEST_INFODIRECTORY , RememberLastUsedValues)
    COPY_LINEENTRY (Acquisition.InfoFilename  , CFG_DLGACQUIRE_DEST_INFOFILENAME  , RememberLastUsedValues)
+   CHK (AdjustPathAndFilename (Acquisition.ImagePath, Acquisition.ImageFilename))
+   CHK (AdjustPathAndFilename (Acquisition.InfoPath , Acquisition.InfoFilename ))
 
    COPY_CHECKBOX (Acquisition.CalcMD5   , CFG_DLGACQUIRE_HASH_CALC_MD5   , RememberLastUsedValues)
    COPY_CHECKBOX (Acquisition.CalcSHA1  , CFG_DLGACQUIRE_HASH_CALC_SHA1  , RememberLastUsedValues)
