@@ -9,32 +9,36 @@
 //  Module:         Acquisition dialog
 // ****************************************************************************
 
-// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014 Guy Voncken
+// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016 Guy Voncken
 //
-// This file is part of guymager.
+// This file is part of Guymager.
 //
-// guymager is free software: you can redistribute it and/or modify
+// Guymager is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation, either version 2 of the License, or
 // (at your option) any later version.
 //
-// guymager is distributed in the hope that it will be useful,
+// Guymager is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with guymager. If not, see <http://www.gnu.org/licenses/>.
+// along with Guymager. If not, see <http://www.gnu.org/licenses/>.
 
 #ifndef __DLGACQUIRE_H__
 #define __DLGACQUIRE_H__
 
-#include <QtGui> //lint !e537 Repeated include
-
 #ifndef __COMMON_H__
    #include "common.h"
 #endif
 
+#if (QT_VERSION >= 0x050000)
+   #include <QtWidgets> //lint !e537 Repeated include
+#else
+   #include <QtGui>     //lint !e537 Repeated include
+#endif
+
 #ifndef __DEVICE_H__
   #include "device.h"
 #endif
@@ -60,13 +64,14 @@ class t_DlgAcquire: public QDialog
 
    public:
       t_DlgAcquire ();
-      t_DlgAcquire (t_pDevice pDevice, bool Clone, t_pDeviceList pDeviceList, bool Duplicate = false, QWidget *pParent=NULL, Qt::WFlags Flags=0, bool ForceLastEnteredValues=false);
+      t_DlgAcquire (t_pDevice pDevice, bool Clone, t_pDeviceList pDeviceList, bool Duplicate = false, QWidget *pParent=NULL, Qt::WindowFlags Flags=0, bool ForceLastEnteredValues=false, t_pAcquisition pAcquisition1=NULL);
      ~t_DlgAcquire ();
 
       APIRET GetParameters (t_Acquisition &Acquisition, bool RememberLastUsedValues=true);
    private:
       t_CfgEntryMode EntryMode            (t_pCfgDlgAcquireField pField);
       APIRET         AddField             (t_pDevice pDevice, t_pCfgDlgAcquireField pField, QGridLayout *pLayout, int *pRow, int *pCol, bool ForceLastEnteredValues);
+      APIRET         AdjustPathAndFilename(QString &Path, QString &Filename);
       APIRET         CheckWriteAccess     (t_pcDevice pDevice, const QString &Path, const QString &Filename, bool &Ok);
       APIRET         CreateDeviceTable    (t_pDeviceList pDeviceList, t_pDevice pDeviceSrc, QTableWidget **ppTable);
       APIRET         InsertDeviceTableRow (QTableWidget *pTable, int Row, t_pDeviceList pDeviceList, t_pDevice pDevSrc, t_pDevice pDev);
