@@ -9,22 +9,28 @@
 //  Module:         Different message boxes we need all the time
 // ****************************************************************************
 
-// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014 Guy Voncken
+// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016 Guy Voncken
 //
-// This file is part of guymager.
+// This file is part of Guymager.
 //
-// guymager is free software: you can redistribute it and/or modify
+// Guymager is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation, either version 2 of the License, or
 // (at your option) any later version.
 //
-// guymager is distributed in the hope that it will be useful,
+// Guymager is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with guymager. If not, see <http://www.gnu.org/licenses/>.
+// along with Guymager. If not, see <http://www.gnu.org/licenses/>.
+
+#if (QT_VERSION >= 0x050000)
+   #include <QtWidgets> //lint !e537 Repeated include
+#else
+   #include <QtGui>     //lint !e537 Repeated include
+#endif
 
 #include "dlgmessage.h"
 #include "config.h"
@@ -53,7 +59,7 @@ t_DlgMessage::t_DlgMessage ()
    CHK_EXIT (ERROR_DLGMESSAGE_CONSTRUCTOR_NOT_SUPPORTED)
 } //lint !e1401 pOwn not initialised
 
-t_DlgMessage::t_DlgMessage (const QString &Title, QString Message, bool Monospaced, QWidget *pParent, Qt::WFlags Flags)
+t_DlgMessage::t_DlgMessage (const QString &Title, QString Message, bool Monospaced, QWidget *pParent, Qt::WindowFlags Flags)
    :QDialog (pParent, Flags)
 {
    static bool  Initialised = false;
@@ -155,7 +161,7 @@ t_DlgMessage::~t_DlgMessage ()
    delete pOwn;
 }
 
-APIRET t_DlgMessage::Show (const QString &Title, const QString &Message, bool Monospaced, QWidget *pParent, Qt::WFlags Flags)
+APIRET t_DlgMessage::Show (const QString &Title, const QString &Message, bool Monospaced, QWidget *pParent, Qt::WindowFlags Flags)
 {
    t_DlgMessage *pDlg;
 
