@@ -9,32 +9,36 @@
 //  Module:         Wait dialog
 // ****************************************************************************
 
-// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014 Guy Voncken
+// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016 Guy Voncken
 //
-// This file is part of guymager.
+// This file is part of Guymager.
 //
-// guymager is free software: you can redistribute it and/or modify
+// Guymager is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation, either version 2 of the License, or
 // (at your option) any later version.
 //
-// guymager is distributed in the hope that it will be useful,
+// Guymager is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with guymager. If not, see <http://www.gnu.org/licenses/>.
+// along with Guymager. If not, see <http://www.gnu.org/licenses/>.
 
 #ifndef __DLGWAIT_H__
 #define __DLGWAIT_H__
 
-#include <QtGui> //lint !e537 Repeated include
-
 #ifndef __COMMON_H__
    #include "common.h"
 #endif
 
+#if (QT_VERSION >= 0x050000)
+   #include <QtWidgets> //lint !e537 Repeated include
+#else
+   #include <QtGui>     //lint !e537 Repeated include
+#endif
+
 class t_DlgWaitLocal;
 
 class t_DlgWait: public QDialog
@@ -43,7 +47,7 @@ class t_DlgWait: public QDialog
 
    public:
       t_DlgWait ();
-      t_DlgWait (const QString &Title, const QString &Message, QWidget *pParent=NULL, Qt::WFlags Flags=0);
+      t_DlgWait (const QString &Title, const QString &Message, QWidget *pParent=NULL, Qt::WindowFlags Flags=0);
      ~t_DlgWait ();
 
       static APIRET Show (const QString &Title, const QString &Message);
