@@ -9,22 +9,22 @@
 //  Module:         Everything related to file names, extension names, paths...
 // ****************************************************************************
 
-// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014 Guy Voncken
+// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016 Guy Voncken
 //
-// This file is part of guymager.
+// This file is part of Guymager.
 //
-// guymager is free software: you can redistribute it and/or modify
+// Guymager is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation, either version 2 of the License, or
 // (at your option) any later version.
 //
-// guymager is distributed in the hope that it will be useful,
+// Guymager is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with guymager. If not, see <http://www.gnu.org/licenses/>.
+// along with Guymager. If not, see <http://www.gnu.org/licenses/>.
 
 #include "common.h"
 
@@ -83,6 +83,7 @@ APIRET t_File::GetFormatDescription (t_Format Format, bool Clone, int DdSplitDec
             #if (LIBEWF_VERSION >= 20130416)
             case LIBEWF_FORMAT_ENCASE7: SubFormat="Encase7" ; break;
             case LIBEWF_FORMAT_LINEN7 : SubFormat="Linen7"  ; break;
+            case LIBEWF_FORMAT_EWFX   : SubFormat="EWFX"    ; break;
             #endif
             case AEWF                 : SubFormat="Guymager"; break;
             default                   : CHK (ERROR_FILE_INVALID_EWF_FORMAT)
@@ -135,6 +136,7 @@ APIRET t_File::GetFormatExtension (t_Format Format, bool Clone, int DdSplitDecim
             #if (LIBEWF_VERSION >= 20130416)
             case LIBEWF_FORMAT_ENCASE7:
             case LIBEWF_FORMAT_LINEN7 :
+            case LIBEWF_FORMAT_EWFX   :
             #endif
             case LIBEWF_FORMAT_FTK    :
             case AEWF                 : Wild=".E??"; Human=".Exx"; break;
