@@ -1,10 +1,10 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="de_DE" sourcelanguage="en">
+<TS version="2.1" language="de_DE" sourcelanguage="en">
 <context>
     <name>QObject</name>
     <message>
-        <location filename="main.cpp" line="+465"/>
+        <location filename="main.cpp" line="+508"/>
         <source>Missing root rights</source>
         <comment>Dialog title</comment>
         <translation>Keine Root-Rechte</translation>
@@ -17,14 +17,14 @@ Continue anyway?</source>
 Trotzdem fortfahren?</translation>
     </message>
     <message>
-        <location filename="threadwrite.cpp" line="+1468"/>
+        <location filename="threadwrite.cpp" line="+1480"/>
         <source>Deleting %1</source>
         <translation>Lösche %1</translation>
     </message>
     <message>
-        <location filename="dlgabort.cpp" line="+82"/>
-        <location filename="dlgacquire.cpp" line="+795"/>
-        <location filename="dlgdirsel.cpp" line="+100"/>
+        <location filename="dlgabort.cpp" line="+83"/>
+        <location filename="dlgacquire.cpp" line="+811"/>
+        <location filename="dlgdirsel.cpp" line="+106"/>
         <source>Ok</source>
         <translation>Ok</translation>
     </message>
@@ -42,7 +42,7 @@ Trotzdem fortfahren?</translation>
         <translation>Linux dd-Image</translation>
     </message>
     <message>
-        <location line="+23"/>
+        <location line="+24"/>
         <source>Expert Witness Format, sub-format %1</source>
         <translation>EWF-Format, Unterformat %1</translation>
     </message>
@@ -52,7 +52,7 @@ Trotzdem fortfahren?</translation>
         <translation>AFF-Format</translation>
     </message>
     <message>
-        <location filename="threadscan.cpp" line="+1010"/>
+        <location filename="threadscan.cpp" line="+1440"/>
         <source>Guymager cannot scan the devices connected to this computer.</source>
         <translation>Guymager kann die angeschlossenen Geräte nicht abfragen.</translation>
     </message>
@@ -72,7 +72,7 @@ Trotzdem fortfahren?</translation>
         <translation>Methode &quot;%1&quot;</translation>
     </message>
     <message>
-        <location filename="file.cpp" line="-28"/>
+        <location filename="file.cpp" line="-29"/>
         <source>Creation of a clone</source>
         <translation>Erstellen eines Klons</translation>
     </message>
@@ -167,7 +167,7 @@ Belegung
 [%]</translation>
     </message>
     <message>
-        <location filename="mainwindow.h" line="+42"/>
+        <location filename="mainwindow.h" line="+47"/>
         <source>SerialNr</source>
         <translation>Serien-
 nummer</translation>
@@ -279,7 +279,7 @@ Geschwindigkeit
         <translation type="obsolete">Bemerkungen</translation>
     </message>
     <message>
-        <location filename="dlgacquire.cpp" line="-383"/>
+        <location filename="dlgacquire.cpp" line="-392"/>
         <source>Remark</source>
         <translation>Bemerkung</translation>
     </message>
@@ -316,8 +316,8 @@ Geschwindigkeit
 <context>
     <name>t_DlgAcquire</name>
     <message>
-        <location filename="config.h" line="+266"/>
-        <location filename="table.cpp" line="+309"/>
+        <location filename="config.h" line="+274"/>
+        <location filename="table.cpp" line="+345"/>
         <source>EwfCaseNumber</source>
         <translation>Fallnummer</translation>
     </message>
@@ -356,12 +356,12 @@ Geschwindigkeit
         <translation>Info-Dateiname (ohne Endung)</translation>
     </message>
     <message>
-        <location filename="dlgacquire.cpp" line="+210"/>
+        <location filename="dlgacquire.cpp" line="+212"/>
         <source>File format</source>
         <translation>Dateiformat</translation>
     </message>
     <message>
-        <location line="+84"/>
+        <location line="+91"/>
         <source>Destination</source>
         <translation>Ziel</translation>
     </message>
@@ -371,30 +371,29 @@ Geschwindigkeit
         <translation>Konfigurationsparameter WriteToDevNull ist gesetzt!</translation>
     </message>
     <message>
-        <location line="+293"/>
+        <location line="+297"/>
         <source>Select destination directory</source>
         <comment>Dialog title</comment>
         <translation>Zielverzeichnis auswählen</translation>
     </message>
     <message>
-        <location line="+256"/>
         <source>The filenames contain special characters which are not allowed. Guymager suggests the following changes:
 	Image filename: %1
 	Info filename: %2
 Do you accept these changes?</source>
-        <translation>Die Dateinamen enthalten unerlaubte Sonderzeichen. Guymager schlägt stattdessen folgende Namen vor:
+        <translation type="vanished">Die Dateinamen enthalten unerlaubte Sonderzeichen. Guymager schlägt stattdessen folgende Namen vor:
 	Image-Dateiname: %1
 	Info-Dateiname: %2
 Sind Sie mit diesen Änderungen einverstanden?</translation>
     </message>
     <message>
-        <location line="-625"/>
+        <location line="-380"/>
         <location line="+1"/>
         <source>(file extension %1)</source>
         <translation>(Datei-Endung %1)</translation>
     </message>
     <message>
-        <location line="+629"/>
+        <location line="+688"/>
         <source>Special characters</source>
         <comment>Dialog title</comment>
         <translation>Sonderzeichen</translation>
@@ -410,13 +409,13 @@ Sind Sie mit diesen Änderungen einverstanden?</translation>
         <translation>Info-Verzeichnis</translation>
     </message>
     <message>
-        <location filename="dlgacquire.cpp" line="-1017"/>
+        <location filename="dlgacquire.cpp" line="-1075"/>
         <source>...</source>
         <comment>The directory browse button</comment>
         <translation>...</translation>
     </message>
     <message>
-        <location line="+903"/>
+        <location line="+958"/>
         <source>Access denied</source>
         <comment>Dialog title</comment>
         <translation>Kein Zugriff</translation>
@@ -442,19 +441,19 @@ Sind Sie mit diesen Änderungen einverstanden?</translation>
         <translation>Image nach Akquisition verifizieren (benötigt die doppelte Zeit)</translation>
     </message>
     <message>
-        <location filename="dlgacquire.cpp" line="-425"/>
+        <location filename="dlgacquire.cpp" line="-474"/>
         <source>Hash calculation / verification</source>
         <translation>Hash-Berechnung und Verifizierung</translation>
     </message>
     <message>
-        <location line="+426"/>
+        <location line="+475"/>
         <source>Guymager cannot write to the directory
 	%1
 This may be due to insufficient access rights or unsupported filename characters. Please choose another directory.</source>
         <translation>Der Schreibzugriff auf das Verzeichnis	%1schlug fehl. Dies könnte an unzureichenden Zugriffsrechten oder an Sonderzeichen im Dateinamen liegen. Bitte wählen Sie ein anderes Verzeichnis.</translation>
     </message>
     <message>
-        <location line="-740"/>
+        <location line="-798"/>
         <source>Local device, cannot be written</source>
         <translation>Lokales Gerät, nicht beschreibbar</translation>
     </message>
@@ -474,20 +473,19 @@ This may be due to insufficient access rights or unsupported filename characters
         <translation>Bereit zum Klonen</translation>
     </message>
     <message>
-        <location line="+806"/>
+        <location line="+862"/>
         <source>The split size for the configured EWF format must be in the range %1 - %2 MiB. For bigger files, switch to Encase6 format or Guymager (see Guymager configuration file, parameter EwfFormat).</source>
         <translation>Die Split-Grösse für das konfigurierte EWF-Format muss im Bereich %1 MiB - %2 MiB liegen. Grössere Dateien sind mit den Format Encase6 oder Guymager möglich (siehe Guymager Konfigurationsdatei, Parameter EwfFormat).</translation>
     </message>
     <message>
-        <location line="+31"/>
         <source>The info filename contains special characters which are not allowed. Guymager suggests the following changes:
 	%1
 Do you accept these changes?</source>
-        <translation>Der Info-Dateiname enthält unerlaubte Sonderzeichen. Guymager schlägt stattdessen folgenden Namen vor:	 %1
+        <translation type="vanished">Der Info-Dateiname enthält unerlaubte Sonderzeichen. Guymager schlägt stattdessen folgenden Namen vor:	 %1
 Sind Sie mit diesen Änderungen einverstanden?</translation>
     </message>
     <message>
-        <location line="+95"/>
+        <location line="+174"/>
         <source>Files exist</source>
         <comment>Dialog title</comment>
         <translation>Dateien existieren bereits</translation>
@@ -498,7 +496,7 @@ Sind Sie mit diesen Änderungen einverstanden?</translation>
         <translation>Die Image- oder Info-Dateien existieren bereits. Möchten Sie sie überschreiben?</translation>
     </message>
     <message>
-        <location line="-777"/>
+        <location line="-881"/>
         <source>Clone %1</source>
         <comment>Dialog title, %1 is the device (for instance /dev/hdc)</comment>
         <translation>Gerät %1 klonen</translation>
@@ -530,12 +528,12 @@ Sind Sie mit diesen Änderungen einverstanden?</translation>
         <translation>Image splitten</translation>
     </message>
     <message>
-        <location filename="dlgacquire.cpp" line="+215"/>
+        <location filename="dlgacquire.cpp" line="+217"/>
         <source>(file extension %1 or %2)</source>
         <translation>(Datei-Endung %1 oder %2)</translation>
     </message>
     <message>
-        <location line="+564"/>
+        <location line="+618"/>
         <location line="+15"/>
         <location line="+12"/>
         <source>Incorrect value</source>
@@ -548,7 +546,18 @@ Sind Sie mit diesen Änderungen einverstanden?</translation>
         <translation>Die Grösse %1 für die Split-Dateien ist ungültig. Bitte geben Sie einen positiven Wert ein.</translation>
     </message>
     <message>
-        <location line="+154"/>
+        <location line="+163"/>
+        <source>Files already used</source>
+        <comment>Dialog title</comment>
+        <translation>Datei bereits belegt</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>The image or info files already are used in the acquisition of %1. Please chose different ones.</source>
+        <translation>Die Image- oder Info-Dateien werden bereits in einer anderen Akquisition (%1) benutzt. Bitte wählen Sie andere Namen.</translation>
+    </message>
+    <message>
+        <location line="+38"/>
         <source>The info file already exists. Do you want to overwrite it?</source>
         <translation>Die Info-Datei existiert bereits. Möchten Sie sie überschreiben?</translation>
     </message>
@@ -562,7 +571,7 @@ Sind Sie mit diesen Änderungen einverstanden?</translation>
         <translation> </translation>
     </message>
     <message>
-        <location filename="dlgacquire.cpp" line="-139"/>
+        <location filename="dlgacquire.cpp" line="-187"/>
         <source>The split size for the selected image format must be in the range %1MiB - %2EiB.</source>
         <translation>Die Split-Grösse für das gewählte Datei-Format muss im Bereich %1 MiB - %2 EiB liegen.</translation>
     </message>
@@ -575,7 +584,7 @@ Sind Sie mit diesen Änderungen einverstanden?</translation>
         <translation type="obsolete">Die Split-Grösse für das konfigurierte EWF-Format muss im Bereich %1 MiB - %2 MiB liegen. Grössere Dateien sind ab dem Format Encase6 möglich (siehe Guymager Konfigurationsdatei, Parameter EwfFormat).</translation>
     </message>
     <message>
-        <location line="+165"/>
+        <location line="+213"/>
         <source>Large amount of segment files</source>
         <comment>Dialog title</comment>
         <translation>Anzahl Image-Segmente</translation>
@@ -610,7 +619,7 @@ Möchten Sie die Akquisition trotzdem starten?</translation>
         <translation>SHA-1 berechnen</translation>
     </message>
     <message>
-        <location filename="dlgacquire.cpp" line="-992"/>
+        <location filename="dlgacquire.cpp" line="-1096"/>
         <source>Selected for first acquisition</source>
         <translation>Als 1. Akquisitionsziel ausgewählt</translation>
     </message>
@@ -627,7 +636,57 @@ Möchten Sie die Akquisition trotzdem starten?</translation>
         <translation>Duplizierter Klon von %1</translation>
     </message>
     <message>
-        <location line="+716"/>
+        <location line="+570"/>
+        <source>Path not found</source>
+        <comment>Dialog title</comment>
+        <translation>Nicht existierender Pfad</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>The destination directory
+   %1
+doesn&apos;t exist. Do you want to create it?</source>
+        <translation>Das Zielverzeichnis
+   %1
+existiert nicht. Möchten Sie es anlegen?</translation>
+    </message>
+    <message>
+        <location line="+169"/>
+        <source>The directory or file names contain special characters which are not allowed. Guymager suggests the following changes:</source>
+        <translation>Die Verzeichnis- oder Dateinamen enthält unerlaubte Sonderzeichen. Guymager schlägt stattdessen folgenden Namen vor:</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>
+   Image directory:	%1</source>
+        <translation>   Image-Verzeichnis:	%1</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>
+   Image filename:	%1</source>
+        <translation>   Image-Datei: 	%1</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>
+   Info directory:	%1</source>
+        <translation>   Info-Verzeichnis:	%1</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>
+   Info filename:	%1</source>
+        <translation>   Info-Datei:	%1</translation>
+    </message>
+    <message>
+        <location line="+2"/>
+        <source>
+Do you accept these changes?</source>
+        <translation>Sind Sie mit diesen Änderungen einverstanden?</translation>
+    </message>
+    <message>
+        <location line="+33"/>
         <source>Destination in use</source>
         <comment>Dialog title</comment>
         <translation>Ziel bereits belegt </translation>
@@ -649,7 +708,7 @@ Möchten Sie die Akquisition trotzdem starten?</translation>
         <translation>Die Info-Datei ist bereits durch das erste Image belegt.</translation>
     </message>
     <message>
-        <location line="-541"/>
+        <location line="-595"/>
         <location line="+21"/>
         <source>Back...</source>
         <translation>Zurück...</translation>
@@ -661,12 +720,12 @@ Möchten Sie die Akquisition trotzdem starten?</translation>
         <translation>Image duplizieren...</translation>
     </message>
     <message>
-        <location line="-177"/>
+        <location line="-184"/>
         <source>Duplicate image settings</source>
         <translation>Einstellungen für dupliziertes Image</translation>
     </message>
     <message>
-        <location line="+804"/>
+        <location line="+906"/>
         <source>There possibly is not enough space left on the destination path.
 Source data size: %1
 Free space on destination: %2
@@ -681,7 +740,7 @@ Möchten Sie trotzdem fortfahren?</translation>
 <context>
     <name>t_DlgAutoExit</name>
     <message>
-        <location filename="dlgautoexit.cpp" line="+79"/>
+        <location filename="dlgautoexit.cpp" line="+85"/>
         <source>Abort</source>
         <translation>Abbruch</translation>
     </message>
@@ -726,7 +785,7 @@ Guymager beendet sich automatisch in %1 Sekunden.</translation>
 <context>
     <name>t_DlgMessage</name>
     <message>
-        <location filename="dlgmessage.cpp" line="+94"/>
+        <location filename="dlgmessage.cpp" line="+100"/>
         <source>Close</source>
         <translation>Schließen</translation>
     </message>
@@ -734,7 +793,7 @@ Guymager beendet sich automatisch in %1 Sekunden.</translation>
 <context>
     <name>t_Info</name>
     <message>
-        <location filename="info.cpp" line="+200"/>
+        <location filename="info.cpp" line="+201"/>
         <source>Command executed: %1</source>
         <translation>Ausgeführter Befehl: %1</translation>
     </message>
@@ -752,7 +811,7 @@ Guymager beendet sich automatisch in %1 Sekunden.</translation>
 <context>
     <name>t_InfoField</name>
     <message>
-        <location filename="infofield.cpp" line="+105"/>
+        <location filename="infofield.cpp" line="+109"/>
         <source>Size</source>
         <translation>Größe</translation>
     </message>
@@ -868,7 +927,7 @@ Guymager beendet sich automatisch in %1 Sekunden.</translation>
 <context>
     <name>t_MainWindow</name>
     <message>
-        <location filename="device.cpp" line="+391"/>
+        <location filename="device.cpp" line="+398"/>
         <source>Local device</source>
         <translation>Lokales Gerät</translation>
     </message>
@@ -892,7 +951,7 @@ Guymager beendet sich automatisch in %1 Sekunden.</translation>
         <translation type="obsolete">Abbruch - Fehler &quot;Reason none&quot;</translation>
     </message>
     <message>
-        <location line="-353"/>
+        <location line="-355"/>
         <source>Aborted by user</source>
         <translation>Abbruch durch Benutzer</translation>
     </message>
@@ -905,7 +964,7 @@ Guymager beendet sich automatisch in %1 Sekunden.</translation>
         <translation type="obsolete">Abbruch - Lesefehler</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="+281"/>
+        <location filename="mainwindow.cpp" line="+291"/>
         <source>&amp;Rescan</source>
         <translation>&amp;Auffrischen</translation>
     </message>
@@ -915,7 +974,13 @@ Guymager beendet sich automatisch in %1 Sekunden.</translation>
         <translation>F5</translation>
     </message>
     <message>
-        <location line="+346"/>
+        <location line="+195"/>
+        <source>Device already contained</source>
+        <comment>Dialog title</comment>
+        <translation>Gerät bereits vorhanden</translation>
+    </message>
+    <message>
+        <location line="+154"/>
         <source>There are active acquisitions. Do you really want to abort them and quit?</source>
         <translation>GUYMAGER hat noch Akquisitionen laufen. Möchten Sie diese abbrechen und das Programm verlassen?</translation>
     </message>
@@ -959,7 +1024,7 @@ Benutzt libguytools %5</translation>
         <translation>GUYMAGER verlassen</translation>
     </message>
     <message>
-        <location line="-341"/>
+        <location line="-344"/>
         <source>&amp;Devices</source>
         <translation>&amp;Geräte</translation>
     </message>
@@ -1002,7 +1067,7 @@ Benutzt libguytools %5</translation>
         <translation type="obsolete">Verifikation läuft</translation>
     </message>
     <message>
-        <location filename="device.cpp" line="+350"/>
+        <location filename="device.cpp" line="+352"/>
         <source>Device disconnected, acquisition paused</source>
         <translation>Gerät abgeschaltet, Akquisition unterbrochen</translation>
     </message>
@@ -1053,7 +1118,7 @@ Benutzt libguytools %5</translation>
         <translation>Sondergerät hinzufügen</translation>
     </message>
     <message>
-        <location line="+152"/>
+        <location line="+155"/>
         <source>Open File</source>
         <translation>Datei öffnen</translation>
     </message>
@@ -1070,13 +1135,12 @@ Benutzt libguytools %5</translation>
         <translation>Manuell hinzugefügtes Sondergerät</translation>
     </message>
     <message>
-        <location line="+6"/>
         <source>Device alrady contained</source>
         <comment>Dialog title</comment>
-        <translation>Gerät bereits vorhanden</translation>
+        <translation type="vanished">Gerät bereits vorhanden</translation>
     </message>
     <message>
-        <location line="+0"/>
+        <location line="+6"/>
         <source>The selected file or device already is contained in the table.</source>
         <translation>Das Gerät bzw. die Datei ist bereits in der Tabelle enthalten.</translation>
     </message>
@@ -1113,7 +1177,7 @@ Benutzt libguytools %5</translation>
         <translation>nicht feststellbar</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="-170"/>
+        <location filename="mainwindow.cpp" line="-173"/>
         <source>Exit after acquisitions completed</source>
         <translation>Guymager nach Abschluss aller Akquisitionen beenden</translation>
     </message>
@@ -1126,7 +1190,7 @@ Benutzt libguytools %5</translation>
         <translation type="obsolete">Abbruch - Startfehler Akquisition</translation>
     </message>
     <message>
-        <location line="+402"/>
+        <location line="+405"/>
         <source>(not used as Guymager currently is configured to use its own EWF module)</source>
         <translation>(inaktiv, da das Guymager-interne EWF-Modul konfiguriert ist)</translation>
     </message>
@@ -1148,7 +1212,7 @@ Benutzt libewf %4 %5
 Benutzt libguytools %6</translation>
     </message>
     <message>
-        <location filename="device.cpp" line="-466"/>
+        <location filename="device.cpp" line="-468"/>
         <source>Acquisition start failure</source>
         <translation>Startfehler Akquisition</translation>
     </message>
@@ -1203,7 +1267,7 @@ Benutzt libguytools %6</translation>
         <translation>Image 2 Schreibfehler Info-Datei</translation>
     </message>
     <message>
-        <location line="+276"/>
+        <location line="+278"/>
         <source>Running</source>
         <translation>Akquisition läuft</translation>
     </message>
@@ -1276,7 +1340,7 @@ Benutzt libguytools %6</translation>
         <translation>Verifikation schlug fehl</translation>
     </message>
     <message>
-        <location line="-393"/>
+        <location line="-395"/>
         <source>Too many bad sectors</source>
         <translation>Zu viele schlechte Sektoren</translation>
     </message>
@@ -1286,7 +1350,7 @@ Benutzt libguytools %6</translation>
         <translation>Gerät abgeschaltet - Timeout</translation>
     </message>
     <message>
-        <location line="+294"/>
+        <location line="+296"/>
         <source>Queued</source>
         <translation>In Warteschlange</translation>
     </message>
@@ -1294,7 +1358,7 @@ Benutzt libguytools %6</translation>
 <context>
     <name>t_Table</name>
     <message>
-        <location filename="table.cpp" line="-164"/>
+        <location filename="table.cpp" line="-190"/>
         <source>Local Device - cannot be acquired</source>
         <translation>Lokales Gerät - kann nicht akquiriert werden</translation>
     </message>
@@ -1305,31 +1369,49 @@ Benutzt libguytools %6</translation>
         <translation>Info</translation>
     </message>
     <message>
-        <location line="+138"/>
+        <location line="+149"/>
         <source>Device info</source>
         <comment>Dialog title</comment>
         <translation>Geräte-Informationen</translation>
     </message>
     <message>
-        <location line="+21"/>
+        <location line="+26"/>
         <source>GUYMAGER ACQUISITION INFO FILE</source>
         <comment>Info file</comment>
         <translation>GUYMAGER INFO-DATEI ZUR AKQUISITION</translation>
     </message>
     <message>
-        <location line="+6"/>
+        <location line="+13"/>
         <source>Guymager</source>
         <comment>Info file</comment>
         <translation>Guymager</translation>
     </message>
     <message>
-        <location line="+11"/>
+        <location line="+7"/>
+        <source>Host name:: %1</source>
+        <comment>Info file</comment>
+        <translation>Host-Name:: %1</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Domain name:: %1</source>
+        <comment>Info file</comment>
+        <translation>Doman-Name:: %1</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>System:: %1</source>
+        <comment>Info file</comment>
+        <translation>System:: %1</translation>
+    </message>
+    <message>
+        <location line="+5"/>
         <source>Device information</source>
         <comment>Info file</comment>
         <translation>Geräte-Informationen</translation>
     </message>
     <message>
-        <location line="+528"/>
+        <location line="+579"/>
         <source>Finished successfully</source>
         <comment>Info file</comment>
         <translation>Erfolgreich beendet</translation>
@@ -1341,13 +1423,13 @@ Benutzt libguytools %6</translation>
         <translation>(mit %1 defekten Sektoren)</translation>
     </message>
     <message>
-        <location line="+22"/>
+        <location line="-45"/>
         <source>Aborted by user</source>
         <comment>Info file</comment>
         <translation>Abbruch durch Benutzer</translation>
     </message>
     <message>
-        <location line="+28"/>
+        <location line="+34"/>
         <source>Aborted because of image write error</source>
         <comment>Info file</comment>
         <translation>Abbruch wegen Fehler beim Schreiben der Image-Datei</translation>
@@ -1358,19 +1440,19 @@ Benutzt libguytools %6</translation>
         <translation type="obsolete">Abbruch, unbekannter Grund (%1)</translation>
     </message>
     <message>
-        <location line="+8"/>
+        <location line="+30"/>
         <source>Strange state (%1)</source>
         <comment>Info file</comment>
         <translation>Unbekannter Zustand (%1)</translation>
     </message>
     <message>
-        <location line="+2"/>
+        <location line="+3"/>
         <source>State: %1</source>
         <comment>Info file</comment>
         <translation>Status: %1</translation>
     </message>
     <message>
-        <location line="-163"/>
+        <location line="-174"/>
         <source>During verification, %1 bad sectors have been encountered. The sector numbers are:</source>
         <comment>Info file</comment>
         <translation>Während der MD5-Verifizierung wurden %1 defekte Sektoren festgestellt. Die Sektor-Nummern sind:</translation>
@@ -1394,13 +1476,13 @@ Benutzt libguytools %6</translation>
         <translation>Bei der Akquisition wurden keine defekte Sektoren entdeckt.</translation>
     </message>
     <message>
-        <location line="+76"/>
+        <location line="+58"/>
         <source>(during acquisition)</source>
         <comment>Info file</comment>
         <translation>(während der Akquisition)</translation>
     </message>
     <message>
-        <location line="+77"/>
+        <location line="+106"/>
         <source>(ISO format YYYY-MM-DD HH:MM:SS)</source>
         <translation>(ISO-Format JJJJ-MM-TT SS:MM:ss)</translation>
     </message>
@@ -1410,7 +1492,7 @@ Benutzt libguytools %6</translation>
         <translation>Akquisition vor Beginn der MD5-Verifizierung abgebrochen</translation>
     </message>
     <message>
-        <location line="-629"/>
+        <location line="-642"/>
         <source>Linux device:: %1</source>
         <comment>Info file</comment>
         <translation>Linux-Gerät:: %1</translation>
@@ -1422,7 +1504,7 @@ Benutzt libguytools %6</translation>
         <translation>Grösse:: %1 (%2)</translation>
     </message>
     <message>
-        <location line="+630"/>
+        <location line="+643"/>
         <location line="+24"/>
         <source>Acquisition started:: %1</source>
         <comment>Info file</comment>
@@ -1449,19 +1531,19 @@ Benutzt libguytools %6</translation>
         <translation>Geschwindigkeit Akquisition:: %1 MByte/s (%2 Stunden, %3 Minuten und %4 Sekunden)</translation>
     </message>
     <message>
-        <location line="-155"/>
+        <location line="-164"/>
         <source>--</source>
         <comment>Info file</comment>
         <translation>--</translation>
     </message>
     <message>
-        <location line="+74"/>
+        <location line="+83"/>
         <source>MD5 hash:: %1</source>
         <comment>Info file</comment>
         <translation>MD5-Hash:: %1</translation>
     </message>
     <message>
-        <location line="-603"/>
+        <location line="-619"/>
         <source>Version:: %1</source>
         <comment>Info file</comment>
         <translation>Version:: %1</translation>
@@ -1491,7 +1573,7 @@ Benutzt libguytools %6</translation>
         <translation>Version libguytools:: %1</translation>
     </message>
     <message>
-        <location line="+667"/>
+        <location line="+683"/>
         <source>Verification speed:: %1 MByte/s (%2 hours, %3 minutes and %4 seconds)</source>
         <comment>Info file</comment>
         <translation>Geschwindigkeit MD5-Verifizierung:: %1 MByte/s (%2 Stunden, %3 Minuten und %4 Sekunden)</translation>
@@ -1502,7 +1584,7 @@ Benutzt libguytools %6</translation>
         <translation type="obsolete">Hash-Berechnung:: aus</translation>
     </message>
     <message>
-        <location line="-626"/>
+        <location line="-639"/>
         <source>Source verification:: on</source>
         <comment>Info file</comment>
         <translation>Verifikation Quellmedium:: ein</translation>
@@ -1514,13 +1596,13 @@ Benutzt libguytools %6</translation>
         <translation>Verifikation Quellmedium:: aus</translation>
     </message>
     <message>
-        <location line="+523"/>
+        <location line="+507"/>
         <source>(during source verification)</source>
         <comment>Info file</comment>
         <translation>(während der Verifikation des Quellmediums)</translation>
     </message>
     <message>
-        <location line="+40"/>
+        <location line="+69"/>
         <source>SHA256 hash:: %1</source>
         <comment>Info file</comment>
         <translation>SHA256-Hash:: %1</translation>
@@ -1541,7 +1623,7 @@ Benutzt libguytools %6</translation>
         <translation type="obsolete">Hash-Berechnung:: SHA-256</translation>
     </message>
     <message>
-        <location line="-571"/>
+        <location line="-584"/>
         <source>Image path and file name:: %1</source>
         <comment>Info file</comment>
         <translation>Image-Pfad und Datei:: %1</translation>
@@ -1565,13 +1647,26 @@ Benutzt libguytools %6</translation>
         <translation>Verifikation Image-Datei:: aus</translation>
     </message>
     <message>
-        <location line="+535"/>
+        <location line="+516"/>
+        <source>Aborted, too many bad sectors (&gt; %1)</source>
+        <comment>Info file</comment>
+        <translation>Abbruch, zu viele schlechte Sektoren</translation>
+    </message>
+    <message>
+        <location line="+3"/>
+        <source>Aborted because device has been inaccessible for too long (&gt; %1s)</source>
+        <oldsource>Aborted because device has is inaccessible for too long (&gt; %1s)</oldsource>
+        <comment>Info file</comment>
+        <translation>Abbruch, das Gerät ist seit längerem nicht mehr verfügbar (&gt; %1s)</translation>
+    </message>
+    <message>
+        <location line="+6"/>
         <source>Aborted because of image read error during verification</source>
         <comment>Info file</comment>
         <translation>Abbruch wegen Image-Lesefehler während der Verifizierung</translation>
     </message>
     <message>
-        <location line="+19"/>
+        <location line="+42"/>
         <source>MD5 hash verified source:: %1</source>
         <comment>Info file</comment>
         <translation>MD5-Hash Quellmedium verifiziert:: %1</translation>
@@ -1620,13 +1715,13 @@ Benutzt libguytools %6</translation>
         <translation>Versuchen Sie eine erneute Akquisition.</translation>
     </message>
     <message>
-        <location line="-800"/>
+        <location line="-839"/>
         <source>Remove special device</source>
         <comment>Context menu</comment>
         <translation>Sondergerät entfernen</translation>
     </message>
     <message>
-        <location line="+196"/>
+        <location line="+222"/>
         <source>Image meta data</source>
         <comment>Info file</comment>
         <translation>Image Meta-Daten </translation>
@@ -1638,7 +1733,7 @@ Benutzt libguytools %6</translation>
         <translation> - mit Datei-Endung %1</translation>
     </message>
     <message>
-        <location line="-196"/>
+        <location line="-222"/>
         <source>Acquire image</source>
         <comment>Context menu</comment>
         <translation>Image-Datei erstellen</translation>
@@ -1656,7 +1751,7 @@ Benutzt libguytools %6</translation>
         <translation>Abbrechen</translation>
     </message>
     <message>
-        <location line="+186"/>
+        <location line="+212"/>
         <source>Acquisition</source>
         <comment>Info file</comment>
         <translation>Akquisition</translation>
@@ -1668,12 +1763,12 @@ Benutzt libguytools %6</translation>
         <translation>Format:: %1</translation>
     </message>
     <message>
-        <location line="-152"/>
+        <location line="-178"/>
         <source>Device used for cloning - cannot be acquired</source>
         <translation>Gerät durch Klon-Operation belegt - kann nicht akquiriert werden</translation>
     </message>
     <message>
-        <location line="+822"/>
+        <location line="+861"/>
         <source>Generated image files and their MD5 hashes</source>
         <comment>Info file</comment>
         <translation>Erzeugte Image-Dateien und ihre MD5-Hashwerte</translation>
@@ -1693,47 +1788,47 @@ Benutzt libguytools %6</translation>
         <translation>Keine MD5-Hashes verfügbar (der Konfigurationsparameter CalcImageFileMD5 ist abgeschaltet)</translation>
     </message>
     <message>
-        <location line="-837"/>
+        <location line="-876"/>
         <source>Cannot be acquired - see additional state info field</source>
         <translation>Kann nicht akquiriert werden - siehe Status-Zusatzinformation</translation>
     </message>
     <message>
-        <location line="+718"/>
+        <location line="+734"/>
         <source>Aborted because of info file write error</source>
         <comment>Info file</comment>
         <translation>Abbruch wegen Fehler beim Schreiben der Image-Datei</translation>
     </message>
     <message>
-        <location line="-12"/>
+        <location line="-21"/>
         <source>Aborted because acquisition failed to start</source>
         <comment>Info file</comment>
         <translation>Abbruch wegen Fehler beim Start der Akquisition</translation>
     </message>
     <message>
-        <location line="+122"/>
+        <location line="+154"/>
         <source>No MD5 hashes available (the selected EWF format does not support image file hashes)</source>
         <translation>Keine MD5-Hashes verfügbar (das ausgewählte EWF-Format unterstützt das Hashen der Image-Dateien nicht)</translation>
     </message>
     <message>
-        <location line="-659"/>
+        <location line="-672"/>
         <source>Hash calculation:: %1</source>
         <comment>Info file</comment>
         <translation>Hash-Berechnung:: %1</translation>
     </message>
     <message>
-        <location line="+534"/>
+        <location line="+521"/>
         <source>Aborted because of source read error</source>
         <comment>Info file</comment>
         <translation>Abbruch wegen Quellmedium-Lesefehler</translation>
     </message>
     <message>
-        <location line="+16"/>
+        <location line="+19"/>
         <source>Aborted, strange reason (%1 %2)</source>
         <comment>Info file</comment>
         <translation>Abbruch, unbekannter Grund (%1 %2)</translation>
     </message>
     <message>
-        <location line="+14"/>
+        <location line="+37"/>
         <source>SHA1 hash:: %1</source>
         <comment>Info file</comment>
         <translation>SHA1-Hash:: %1</translation>
@@ -1751,13 +1846,13 @@ Benutzt libguytools %6</translation>
         <translation>SHA1-Hash Image verifiziert:: %1</translation>
     </message>
     <message>
-        <location line="-594"/>
+        <location line="-607"/>
         <source>Hidden areas: %1</source>
         <comment>Info file</comment>
         <translation>Versteckte Bereiche: %1</translation>
     </message>
     <message>
-        <location line="+712"/>
+        <location line="+725"/>
         <source>Acquisition/verification aborted - file list may be incomplete</source>
         <translation>Akquisition / Verifikation abgebrochen - die Dateiliste ist möglicherweise unvollständig </translation>
     </message>
@@ -1765,7 +1860,7 @@ Benutzt libguytools %6</translation>
 <context>
     <name>t_ThreadScan</name>
     <message>
-        <location filename="threadscan.cpp" line="+52"/>
+        <location filename="threadscan.cpp" line="+53"/>
         <source>Cannot scan devices</source>
         <comment>Dialog title</comment>
         <translation>Geräteabfrage funktioniert nicht</translation>
