@@ -1,12 +1,12 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="fr">
+<TS version="2.1" language="fr">
 <context>
     <name>QObject</name>
     <message>
-        <location filename="dlgabort.cpp" line="+82"/>
-        <location filename="dlgacquire.cpp" line="+795"/>
-        <location filename="dlgdirsel.cpp" line="+100"/>
+        <location filename="dlgabort.cpp" line="+83"/>
+        <location filename="dlgacquire.cpp" line="+811"/>
+        <location filename="dlgdirsel.cpp" line="+106"/>
         <source>Ok</source>
         <translation>Ok</translation>
     </message>
@@ -24,12 +24,12 @@
         <translation>Image brute Linux dd</translation>
     </message>
     <message>
-        <location line="+23"/>
+        <location line="+24"/>
         <source>Expert Witness Format, sub-format %1</source>
         <translation>Format EWF, sous-format %1 </translation>
     </message>
     <message>
-        <location filename="main.cpp" line="+465"/>
+        <location filename="main.cpp" line="+508"/>
         <source>Missing root rights</source>
         <comment>Dialog title</comment>
         <translation>Droits «root»</translation>
@@ -42,7 +42,7 @@ Continue anyway?</source>
 Continuer quand-même?</translation>
     </message>
     <message>
-        <location filename="threadwrite.cpp" line="+1468"/>
+        <location filename="threadwrite.cpp" line="+1480"/>
         <source>Deleting %1</source>
         <translation>Efface %1</translation>
     </message>
@@ -52,7 +52,7 @@ Continuer quand-même?</translation>
         <translation>Format AFF</translation>
     </message>
     <message>
-        <location filename="threadscan.cpp" line="+1010"/>
+        <location filename="threadscan.cpp" line="+1440"/>
         <source>Guymager cannot scan the devices connected to this computer.</source>
         <translation>Guymager ne peut déterminer les médias connectés.</translation>
     </message>
@@ -72,7 +72,7 @@ Continuer quand-même?</translation>
         <translation>Essayer la méthode &quot;%1&quot;</translation>
     </message>
     <message>
-        <location filename="file.cpp" line="-28"/>
+        <location filename="file.cpp" line="-29"/>
         <source>Creation of a clone</source>
         <translation>Création d&apos;un clone</translation>
     </message>
@@ -169,7 +169,7 @@ des FIFOs
 [%]</translation>
     </message>
     <message>
-        <location filename="mainwindow.h" line="+42"/>
+        <location filename="mainwindow.h" line="+47"/>
         <source>SerialNr</source>
         <translation>Nº de
 série</translation>
@@ -283,7 +283,7 @@ actuelle
         <translation type="obsolete">Remarques</translation>
     </message>
     <message>
-        <location filename="dlgacquire.cpp" line="-383"/>
+        <location filename="dlgacquire.cpp" line="-392"/>
         <source>Remark</source>
         <translation>Remarque</translation>
     </message>
@@ -320,8 +320,8 @@ actuelle
 <context>
     <name>t_DlgAcquire</name>
     <message>
-        <location filename="config.h" line="+266"/>
-        <location filename="table.cpp" line="+309"/>
+        <location filename="config.h" line="+274"/>
+        <location filename="table.cpp" line="+345"/>
         <source>EwfCaseNumber</source>
         <translation>Numéro d&apos;affaire</translation>
     </message>
@@ -360,7 +360,7 @@ actuelle
         <translation>Nom du fichier info</translation>
     </message>
     <message>
-        <location filename="dlgacquire.cpp" line="+210"/>
+        <location filename="dlgacquire.cpp" line="+212"/>
         <source>File format</source>
         <translation>Format fichier</translation>
     </message>
@@ -371,7 +371,7 @@ actuelle
         <translation>(extension %1)</translation>
     </message>
     <message>
-        <location line="+61"/>
+        <location line="+68"/>
         <source>Destination</source>
         <translation>Destination</translation>
     </message>
@@ -381,24 +381,23 @@ actuelle
         <translation>Paramètre de configuration WriteToDevNull activé!</translation>
     </message>
     <message>
-        <location line="+293"/>
+        <location line="+297"/>
         <source>Select destination directory</source>
         <comment>Dialog title</comment>
         <translation>Sélectionner le répertoire de destination</translation>
     </message>
     <message>
-        <location line="+261"/>
+        <location line="+309"/>
         <source>Special characters</source>
         <comment>Dialog title</comment>
         <translation>Charactères spéciaux</translation>
     </message>
     <message>
-        <location line="-5"/>
         <source>The filenames contain special characters which are not allowed. Guymager suggests the following changes:
 	Image filename: %1
 	Info filename: %2
 Do you accept these changes?</source>
-        <translation>Les noms de fichiers contiennent des charactères spéciaux qui ne peuvent être utilisés. Guymager vous propose de modifier les nom comme suit:
+        <translation type="vanished">Les noms de fichiers contiennent des charactères spéciaux qui ne peuvent être utilisés. Guymager vous propose de modifier les nom comme suit:
 	Nom du fichier image: %1
 	Nom du fichier info: %2
 Acceptez-vous ces changement?</translation>
@@ -414,13 +413,13 @@ Acceptez-vous ces changement?</translation>
         <translation>Répertoire info</translation>
     </message>
     <message>
-        <location filename="dlgacquire.cpp" line="-1012"/>
+        <location filename="dlgacquire.cpp" line="-1075"/>
         <source>...</source>
         <comment>The directory browse button</comment>
         <translation>...</translation>
     </message>
     <message>
-        <location line="+903"/>
+        <location line="+958"/>
         <source>Access denied</source>
         <comment>Dialog title</comment>
         <translation>Accès refusé</translation>
@@ -446,12 +445,12 @@ Acceptez-vous ces changement?</translation>
         <translation>Vérifier l&apos;image après l&apos;acquisition (prend le double de temps)</translation>
     </message>
     <message>
-        <location filename="dlgacquire.cpp" line="-425"/>
+        <location filename="dlgacquire.cpp" line="-474"/>
         <source>Hash calculation / verification</source>
         <translation>Calcul / vérification de valeurs hash</translation>
     </message>
     <message>
-        <location line="+426"/>
+        <location line="+475"/>
         <source>Guymager cannot write to the directory
 	%1
 This may be due to insufficient access rights or unsupported filename characters. Please choose another directory.</source>
@@ -460,7 +459,7 @@ This may be due to insufficient access rights or unsupported filename characters
 possiblement à cause de droits d&apos;accès insuffisants. Veuillez choisir un autre répertoire.</translation>
     </message>
     <message>
-        <location line="-740"/>
+        <location line="-798"/>
         <source>Local device, cannot be written</source>
         <translation>Média local - ne peut être modifié</translation>
     </message>
@@ -480,20 +479,19 @@ possiblement à cause de droits d&apos;accès insuffisants. Veuillez choisir un
         <translation>Bon pour clonage</translation>
     </message>
     <message>
-        <location line="+806"/>
+        <location line="+862"/>
         <source>The split size for the configured EWF format must be in the range %1 - %2 MiB. For bigger files, switch to Encase6 format or Guymager (see Guymager configuration file, parameter EwfFormat).</source>
         <translation>La taille des fragments pour le format EWF configuré doit être comprise entre %1 et %2 MiB. Des fichiers plus grands sont possibles en utilisant les format Encase6 ou Guymager (voir fichier de configuration, paramètre EwfFormat).</translation>
     </message>
     <message>
-        <location line="+31"/>
         <source>The info filename contains special characters which are not allowed. Guymager suggests the following changes:
 	%1
 Do you accept these changes?</source>
-        <translation>Le nom du fichier info contient des charactères spéciaux qui ne peuvent être utilisés. Guymager vous propose de modifier le nom comme suit:	%1
+        <translation type="vanished">Le nom du fichier info contient des charactères spéciaux qui ne peuvent être utilisés. Guymager vous propose de modifier le nom comme suit:	%1
 Acceptez-vous ces changement?</translation>
     </message>
     <message>
-        <location line="+95"/>
+        <location line="+174"/>
         <source>Files exist</source>
         <comment>Dialog title</comment>
         <translation>Fichier existe</translation>
@@ -504,7 +502,7 @@ Acceptez-vous ces changement?</translation>
         <translation>Les fichiers image ou info de ce nom existent déjà. Voulez vous les réécrire?</translation>
     </message>
     <message>
-        <location line="-777"/>
+        <location line="-881"/>
         <source>Clone %1</source>
         <comment>Dialog title, %1 is the device (for instance /dev/hdc)</comment>
         <translation>Cloner %1</translation>
@@ -536,12 +534,12 @@ Acceptez-vous ces changement?</translation>
         <translation>Fragmenter image</translation>
     </message>
     <message>
-        <location filename="dlgacquire.cpp" line="+215"/>
+        <location filename="dlgacquire.cpp" line="+217"/>
         <source>(file extension %1 or %2)</source>
         <translation>(extension %1 ou %2)</translation>
     </message>
     <message>
-        <location line="+564"/>
+        <location line="+618"/>
         <location line="+15"/>
         <location line="+12"/>
         <source>Incorrect value</source>
@@ -554,7 +552,18 @@ Acceptez-vous ces changement?</translation>
         <translation>La valeur %1 pour la taille des fragments n&apos;est pas valable. Veuillez entrer une valuer positive.</translation>
     </message>
     <message>
-        <location line="+154"/>
+        <location line="+163"/>
+        <source>Files already used</source>
+        <comment>Dialog title</comment>
+        <translation>Fichiers déjà utilisés</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>The image or info files already are used in the acquisition of %1. Please chose different ones.</source>
+        <translation>Les fichiers info ou image sont déjà utilisés par une acquisition (%1). Prière de choisir des noms différents.</translation>
+    </message>
+    <message>
+        <location line="+38"/>
         <source>The info file already exists. Do you want to overwrite it?</source>
         <translation>Un fichier info de ce nom existe déjà. Voulez vous le réécrire?</translation>
     </message>
@@ -568,7 +577,7 @@ Acceptez-vous ces changement?</translation>
         <translation> </translation>
     </message>
     <message>
-        <location filename="dlgacquire.cpp" line="-139"/>
+        <location filename="dlgacquire.cpp" line="-187"/>
         <source>The split size for the selected image format must be in the range %1MiB - %2EiB.</source>
         <translation>La taille des fragments du format selectionné doit être comprise entre %1 MiB - %2 EiB.</translation>
     </message>
@@ -581,7 +590,7 @@ Acceptez-vous ces changement?</translation>
         <translation type="obsolete">La taille des fragments pour le format EWF configuré doit être comprise entre %1 et %2 MiB. Des fichiers plus grands sont possibles à partir du format Encase6 (voir fichier de configuration, paramètre EwfFormat).</translation>
     </message>
     <message>
-        <location line="+165"/>
+        <location line="+213"/>
         <source>Large amount of segment files</source>
         <comment>Dialog title</comment>
         <translation>Grand nombre de segments d&apos;image</translation>
@@ -615,7 +624,7 @@ Voulez vous toujours lancer l&apos;acquisition?</translation>
         <translation>Calculer SHA-1</translation>
     </message>
     <message>
-        <location filename="dlgacquire.cpp" line="-992"/>
+        <location filename="dlgacquire.cpp" line="-1096"/>
         <source>Selected for first acquisition</source>
         <translation>Déjà selectionné pour la 1ère acquisition</translation>
     </message>
@@ -632,7 +641,57 @@ Voulez vous toujours lancer l&apos;acquisition?</translation>
         <translation>Clone dupliqué de %1</translation>
     </message>
     <message>
-        <location line="+716"/>
+        <location line="+570"/>
+        <source>Path not found</source>
+        <comment>Dialog title</comment>
+        <translation>Répertoire non-existant</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>The destination directory
+   %1
+doesn&apos;t exist. Do you want to create it?</source>
+        <translation>Le répertoire de destination
+   %1
+n&apos;existe pas. Voulez-vous de créer?</translation>
+    </message>
+    <message>
+        <location line="+169"/>
+        <source>The directory or file names contain special characters which are not allowed. Guymager suggests the following changes:</source>
+        <translation>Les noms des répertoires ou fichiers contiennent des charactères spéciaux qui ne peuvent être utilisés. Guymager vous propose les modifications suivantes:</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>
+   Image directory:	%1</source>
+        <translation>   Répertoire image:	%1</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>
+   Image filename:	%1</source>
+        <translation>   Nom du fichier image:	%1</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>
+   Info directory:	%1</source>
+        <translation>   Répertoire info:	%1</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>
+   Info filename:	%1</source>
+        <translation>   Nom du fichier info:	%1</translation>
+    </message>
+    <message>
+        <location line="+2"/>
+        <source>
+Do you accept these changes?</source>
+        <translation>Acceptez-vous ces changements?</translation>
+    </message>
+    <message>
+        <location line="+33"/>
         <source>Destination in use</source>
         <comment>Dialog title</comment>
         <translation>Destination occupée</translation>
@@ -654,7 +713,7 @@ Voulez vous toujours lancer l&apos;acquisition?</translation>
         <translation>Le fichier info indiquée sera déjà utilisé pour le premier fichier image.</translation>
     </message>
     <message>
-        <location line="-541"/>
+        <location line="-595"/>
         <location line="+21"/>
         <source>Back...</source>
         <translation>Retour...</translation>
@@ -666,12 +725,12 @@ Voulez vous toujours lancer l&apos;acquisition?</translation>
         <translation>Dupliquer fichier image...</translation>
     </message>
     <message>
-        <location line="-177"/>
+        <location line="-184"/>
         <source>Duplicate image settings</source>
         <translation>Paramètres de l&apos;image dupliquée</translation>
     </message>
     <message>
-        <location line="+804"/>
+        <location line="+906"/>
         <source>There possibly is not enough space left on the destination path.
 Source data size: %1
 Free space on destination: %2
@@ -686,7 +745,7 @@ Voulez vous toujours continuer?</translation>
 <context>
     <name>t_DlgAutoExit</name>
     <message>
-        <location filename="dlgautoexit.cpp" line="+79"/>
+        <location filename="dlgautoexit.cpp" line="+85"/>
         <source>Abort</source>
         <translation>Annuler</translation>
     </message>
@@ -731,7 +790,7 @@ Guymager set terminera automatiquement dans %1 secondes.</translation>
 <context>
     <name>t_DlgMessage</name>
     <message>
-        <location filename="dlgmessage.cpp" line="+94"/>
+        <location filename="dlgmessage.cpp" line="+100"/>
         <source>Close</source>
         <translation>Fermer</translation>
     </message>
@@ -739,7 +798,7 @@ Guymager set terminera automatiquement dans %1 secondes.</translation>
 <context>
     <name>t_Info</name>
     <message>
-        <location filename="info.cpp" line="+200"/>
+        <location filename="info.cpp" line="+201"/>
         <source>Command executed: %1</source>
         <translation>Commande  exécutée: %1</translation>
     </message>
@@ -757,7 +816,7 @@ Guymager set terminera automatiquement dans %1 secondes.</translation>
 <context>
     <name>t_InfoField</name>
     <message>
-        <location filename="infofield.cpp" line="+105"/>
+        <location filename="infofield.cpp" line="+109"/>
         <source>Size</source>
         <translation>Capacité</translation>
     </message>
@@ -873,7 +932,7 @@ Guymager set terminera automatiquement dans %1 secondes.</translation>
 <context>
     <name>t_MainWindow</name>
     <message>
-        <location filename="device.cpp" line="+391"/>
+        <location filename="device.cpp" line="+398"/>
         <source>Local device</source>
         <translation>Média local</translation>
     </message>
@@ -897,7 +956,7 @@ Guymager set terminera automatiquement dans %1 secondes.</translation>
         <translation type="obsolete">Abandon - raison «none»</translation>
     </message>
     <message>
-        <location line="-353"/>
+        <location line="-355"/>
         <source>Aborted by user</source>
         <translation>Abandonné par l&apos;utilisateur</translation>
     </message>
@@ -910,7 +969,7 @@ Guymager set terminera automatiquement dans %1 secondes.</translation>
         <translation type="obsolete">Abandon - erreur grave de lecture </translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="+281"/>
+        <location filename="mainwindow.cpp" line="+291"/>
         <source>&amp;Rescan</source>
         <translation>&amp;Actualiser</translation>
     </message>
@@ -955,7 +1014,13 @@ Guymager set terminera automatiquement dans %1 secondes.</translation>
         <translation>A propos de &amp;Qt</translation>
     </message>
     <message>
-        <location line="+326"/>
+        <location line="+175"/>
+        <source>Device already contained</source>
+        <comment>Dialog title</comment>
+        <translation>Média déjà existant</translation>
+    </message>
+    <message>
+        <location line="+154"/>
         <source>Exit GUYMAGER</source>
         <comment>Dialog title</comment>
         <translation>Quitter GUYMAGER</translation>
@@ -1007,7 +1072,7 @@ Utilise libguytools %5</translation>
         <translation type="obsolete">Vérification en cours</translation>
     </message>
     <message>
-        <location filename="device.cpp" line="+350"/>
+        <location filename="device.cpp" line="+352"/>
         <source>Device disconnected, acquisition paused</source>
         <translation>Média déconnecté, acquisition suspendue</translation>
     </message>
@@ -1047,7 +1112,7 @@ Utilise libguytools %5</translation>
         <translation>Oui</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="-431"/>
+        <location filename="mainwindow.cpp" line="-434"/>
         <source>Rescan devices and update table</source>
         <translation>Actualiser la liste des médias connectés</translation>
     </message>
@@ -1058,7 +1123,7 @@ Utilise libguytools %5</translation>
         <translation>Ajouter média spécial</translation>
     </message>
     <message>
-        <location line="+152"/>
+        <location line="+155"/>
         <source>Open File</source>
         <translation>Ouvrir fichier</translation>
     </message>
@@ -1075,13 +1140,12 @@ Utilise libguytools %5</translation>
         <translation>Média spécial ajouté manuellement</translation>
     </message>
     <message>
-        <location line="+6"/>
         <source>Device alrady contained</source>
         <comment>Dialog title</comment>
-        <translation>Média déjà existant</translation>
+        <translation type="vanished">Média déjà existant</translation>
     </message>
     <message>
-        <location line="+0"/>
+        <location line="+6"/>
         <source>The selected file or device already is contained in the table.</source>
         <translation>Le fichier ou média sélectionné figure déja dans la liste.</translation>
     </message>
@@ -1118,7 +1182,7 @@ Utilise libguytools %5</translation>
         <translation>non-détectable</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="-170"/>
+        <location filename="mainwindow.cpp" line="-173"/>
         <source>Exit after acquisitions completed</source>
         <translation>Terminer Guymager à la fin des acquisitions</translation>
     </message>
@@ -1131,7 +1195,7 @@ Utilise libguytools %5</translation>
         <translation type="obsolete">Abandon - Démarrage échoué</translation>
     </message>
     <message>
-        <location line="+402"/>
+        <location line="+405"/>
         <source>(not used as Guymager currently is configured to use its own EWF module)</source>
         <translation>(inactif, Guymager est configuré d&apos;utiliser son propre module EWF)</translation>
     </message>
@@ -1153,7 +1217,7 @@ Utilise libewf %4 %5
 Utilise libguytools %6</translation>
     </message>
     <message>
-        <location filename="device.cpp" line="-466"/>
+        <location filename="device.cpp" line="-468"/>
         <source>Acquisition start failure</source>
         <translation>Démarrage échoué</translation>
     </message>
@@ -1208,7 +1272,7 @@ Utilise libguytools %6</translation>
         <translation>Fichier info 1 erreur d&apos;écriture</translation>
     </message>
     <message>
-        <location line="+276"/>
+        <location line="+278"/>
         <source>Running</source>
         <translation>Acquisition en cours</translation>
     </message>
@@ -1281,7 +1345,7 @@ Utilise libguytools %6</translation>
         <translation>Vérification échouée</translation>
     </message>
     <message>
-        <location line="-393"/>
+        <location line="-395"/>
         <source>Too many bad sectors</source>
         <translation>trop de secteurs mauvais</translation>
     </message>
@@ -1291,7 +1355,7 @@ Utilise libguytools %6</translation>
         <translation>Média déconnecté - délai d&apos;attente dépassé</translation>
     </message>
     <message>
-        <location line="+294"/>
+        <location line="+296"/>
         <source>Queued</source>
         <translation>En file d&apos;attente</translation>
     </message>
@@ -1299,7 +1363,7 @@ Utilise libguytools %6</translation>
 <context>
     <name>t_Table</name>
     <message>
-        <location filename="table.cpp" line="-202"/>
+        <location filename="table.cpp" line="-228"/>
         <source>Info</source>
         <comment>Context menu</comment>
         <translation>Info</translation>
@@ -1310,31 +1374,49 @@ Utilise libguytools %6</translation>
         <translation>Média local - ne peut être acquis</translation>
     </message>
     <message>
-        <location line="+100"/>
+        <location line="+111"/>
         <source>Device info</source>
         <comment>Dialog title</comment>
         <translation>Info média</translation>
     </message>
     <message>
-        <location line="+21"/>
+        <location line="+26"/>
         <source>GUYMAGER ACQUISITION INFO FILE</source>
         <comment>Info file</comment>
         <translation>FICHIER D&apos;INFORMATION POUR ACQUISITION GUYMAGER</translation>
     </message>
     <message>
-        <location line="+6"/>
+        <location line="+13"/>
         <source>Guymager</source>
         <comment>Info file</comment>
         <translation>Guymager</translation>
     </message>
     <message>
-        <location line="+11"/>
+        <location line="+7"/>
+        <source>Host name:: %1</source>
+        <comment>Info file</comment>
+        <translation>Hôte:: %1</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Domain name:: %1</source>
+        <comment>Info file</comment>
+        <translation>Domaine:: %1</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>System:: %1</source>
+        <comment>Info file</comment>
+        <translation>Système:: %1</translation>
+    </message>
+    <message>
+        <location line="+5"/>
         <source>Device information</source>
         <comment>Info file</comment>
         <translation>Information média</translation>
     </message>
     <message>
-        <location line="+528"/>
+        <location line="+579"/>
         <source>Finished successfully</source>
         <comment>Info file</comment>
         <translation>Terminé avec succès</translation>
@@ -1346,13 +1428,13 @@ Utilise libguytools %6</translation>
         <translation>(avec %1 mauvais secteurs)</translation>
     </message>
     <message>
-        <location line="+22"/>
+        <location line="-45"/>
         <source>Aborted by user</source>
         <comment>Info file</comment>
         <translation>Abandonné par l&apos;utilisateur</translation>
     </message>
     <message>
-        <location line="+28"/>
+        <location line="+34"/>
         <source>Aborted because of image write error</source>
         <comment>Info file</comment>
         <translation>Abandonné à cause d&apos;une erreur d&apos;écriture</translation>
@@ -1363,19 +1445,19 @@ Utilise libguytools %6</translation>
         <translation type="obsolete">Abandonné pour une raison inconnue (%1)</translation>
     </message>
     <message>
-        <location line="+8"/>
+        <location line="+30"/>
         <source>Strange state (%1)</source>
         <comment>Info file</comment>
         <translation>Etat inconnu (%1)</translation>
     </message>
     <message>
-        <location line="+2"/>
+        <location line="+3"/>
         <source>State: %1</source>
         <comment>Info file</comment>
         <translation>Etat: %1</translation>
     </message>
     <message>
-        <location line="-163"/>
+        <location line="-174"/>
         <source>During verification, %1 bad sectors have been encountered. The sector numbers are:</source>
         <comment>Info file</comment>
         <translation>Pendant la vérification, %1 mauvais secteurs ont été rencontrés. Leurs numéros sont les suivants:</translation>
@@ -1399,13 +1481,13 @@ Utilise libguytools %6</translation>
         <translation>Aucun mauvais secteur n&apos;a été renconté pendant l&apos;acquisition.</translation>
     </message>
     <message>
-        <location line="+76"/>
+        <location line="+58"/>
         <source>(during acquisition)</source>
         <comment>Info file</comment>
         <translation>(pendant l&apos;acquisition)</translation>
     </message>
     <message>
-        <location line="+77"/>
+        <location line="+106"/>
         <source>(ISO format YYYY-MM-DD HH:MM:SS)</source>
         <translation>(format ISO AAAA-MM-JJ HH:MM:SS)</translation>
     </message>
@@ -1415,7 +1497,7 @@ Utilise libguytools %6</translation>
         <translation>Acquisition abandonnée avant de commencer vérification</translation>
     </message>
     <message>
-        <location line="-629"/>
+        <location line="-642"/>
         <source>Linux device:: %1</source>
         <comment>Info file</comment>
         <translation>Média Linux:: %1</translation>
@@ -1427,7 +1509,7 @@ Utilise libguytools %6</translation>
         <translation>Capacité:: %1 (%2)</translation>
     </message>
     <message>
-        <location line="+630"/>
+        <location line="+643"/>
         <location line="+24"/>
         <source>Acquisition started:: %1</source>
         <comment>Info file</comment>
@@ -1454,19 +1536,19 @@ Utilise libguytools %6</translation>
         <translation>Vitesse de l&apos;acquisition:: %1 MByte/s (%2 heures, %3 minutes et %4 secondes)</translation>
     </message>
     <message>
-        <location line="-155"/>
+        <location line="-164"/>
         <source>--</source>
         <comment>Info file</comment>
         <translation>--</translation>
     </message>
     <message>
-        <location line="+74"/>
+        <location line="+83"/>
         <source>MD5 hash:: %1</source>
         <comment>Info file</comment>
         <translation>Hash MD5:: %1</translation>
     </message>
     <message>
-        <location line="-603"/>
+        <location line="-619"/>
         <source>Version:: %1</source>
         <comment>Info file</comment>
         <translation>Version:: %1</translation>
@@ -1496,7 +1578,7 @@ Utilise libguytools %6</translation>
         <translation>Version libguytools:: %1</translation>
     </message>
     <message>
-        <location line="+667"/>
+        <location line="+683"/>
         <source>Verification speed:: %1 MByte/s (%2 hours, %3 minutes and %4 seconds)</source>
         <comment>Info file</comment>
         <translation>Vitesse de la vérification:: %1 MByte/s (%2 heures, %3 minutes et %4 secondes)</translation>
@@ -1507,7 +1589,7 @@ Utilise libguytools %6</translation>
         <translation type="obsolete">Calculer valeurs hash:: non</translation>
     </message>
     <message>
-        <location line="-626"/>
+        <location line="-639"/>
         <source>Source verification:: on</source>
         <comment>Info file</comment>
         <translation>Relire et vérifier media:: oui</translation>
@@ -1519,13 +1601,13 @@ Utilise libguytools %6</translation>
         <translation>Relire et vérifier media:: non</translation>
     </message>
     <message>
-        <location line="+523"/>
+        <location line="+507"/>
         <source>(during source verification)</source>
         <comment>Info file</comment>
         <translation>(pendant la vérification)</translation>
     </message>
     <message>
-        <location line="+40"/>
+        <location line="+69"/>
         <source>SHA256 hash:: %1</source>
         <comment>Info file</comment>
         <translation>SHA256 hash:: %1</translation>
@@ -1546,7 +1628,7 @@ Utilise libguytools %6</translation>
         <translation type="obsolete">Calculer valeurs hash:: SHA-256</translation>
     </message>
     <message>
-        <location line="-571"/>
+        <location line="-584"/>
         <source>Image path and file name:: %1</source>
         <comment>Info file</comment>
         <translation>Répertoire et fichier image:: %1</translation>
@@ -1570,13 +1652,26 @@ Utilise libguytools %6</translation>
         <translation>Vérification image:: non</translation>
     </message>
     <message>
-        <location line="+535"/>
+        <location line="+516"/>
+        <source>Aborted, too many bad sectors (&gt; %1)</source>
+        <comment>Info file</comment>
+        <translation>Abandonné à cause de trop de secteurs mauvais</translation>
+    </message>
+    <message>
+        <location line="+3"/>
+        <source>Aborted because device has been inaccessible for too long (&gt; %1s)</source>
+        <oldsource>Aborted because device has is inaccessible for too long (&gt; %1s)</oldsource>
+        <comment>Info file</comment>
+        <translation>Abandonné car le média a été inaccessible trop longtemps (&gt; %1s)</translation>
+    </message>
+    <message>
+        <location line="+6"/>
         <source>Aborted because of image read error during verification</source>
         <comment>Info file</comment>
         <translation></translation>
     </message>
     <message>
-        <location line="+19"/>
+        <location line="+42"/>
         <source>MD5 hash verified source:: %1</source>
         <comment>Info file</comment>
         <translation>Hash MD5 source vérifié:: %1</translation>
@@ -1625,13 +1720,13 @@ Utilise libguytools %6</translation>
         <translation>Vous pouvez essayer une nouvelle acquisition du média.</translation>
     </message>
     <message>
-        <location line="-800"/>
+        <location line="-839"/>
         <source>Remove special device</source>
         <comment>Context menu</comment>
         <translation>Effacer média spécial</translation>
     </message>
     <message>
-        <location line="+196"/>
+        <location line="+222"/>
         <source>Image meta data</source>
         <comment>Info file</comment>
         <translation>Méta-données du fichier image</translation>
@@ -1643,7 +1738,7 @@ Utilise libguytools %6</translation>
         <translation> - l&apos;extension fichier est %1</translation>
     </message>
     <message>
-        <location line="-196"/>
+        <location line="-222"/>
         <source>Acquire image</source>
         <comment>Context menu</comment>
         <translation>Acquérir image</translation>
@@ -1661,7 +1756,7 @@ Utilise libguytools %6</translation>
         <translation>Abandonner</translation>
     </message>
     <message>
-        <location line="+186"/>
+        <location line="+212"/>
         <source>Acquisition</source>
         <comment>Info file</comment>
         <translation>Acquisition</translation>
@@ -1673,12 +1768,12 @@ Utilise libguytools %6</translation>
         <translation>Format:: %1</translation>
     </message>
     <message>
-        <location line="-152"/>
+        <location line="-178"/>
         <source>Device used for cloning - cannot be acquired</source>
         <translation>Occupé par opération de clonage - ne peut être  acquéré</translation>
     </message>
     <message>
-        <location line="+822"/>
+        <location line="+861"/>
         <source>Generated image files and their MD5 hashes</source>
         <comment>Info file</comment>
         <translation>Fichiers image et leur valeurs hash MD5</translation>
@@ -1698,47 +1793,47 @@ Utilise libguytools %6</translation>
         <translation>Valeurs hashs MD5 non disponibles (le paramètre de configuration CalcImageFileMD5 est désactivé)</translation>
     </message>
     <message>
-        <location line="-837"/>
+        <location line="-876"/>
         <source>Cannot be acquired - see additional state info field</source>
         <translation>Ne peut être acquéré - voir informations d&apos;état suppl.</translation>
     </message>
     <message>
-        <location line="+718"/>
+        <location line="+734"/>
         <source>Aborted because of info file write error</source>
         <comment>Info file</comment>
         <translation>Abandonné à cause d&apos;une erreur lors de l&apos;écriture du fichier info</translation>
     </message>
     <message>
-        <location line="-12"/>
+        <location line="-21"/>
         <source>Aborted because acquisition failed to start</source>
         <comment>Info file</comment>
         <translation>Abandonné à cause d&apos;erreurs lors du démarrage de l&apos;acquisition</translation>
     </message>
     <message>
-        <location line="+122"/>
+        <location line="+154"/>
         <source>No MD5 hashes available (the selected EWF format does not support image file hashes)</source>
         <translation>Valeurs hashs MD5 non disponibles (le format EWF choisi ne supporte pas le calcul des valeurs hash des fichiers image)</translation>
     </message>
     <message>
-        <location line="-659"/>
+        <location line="-672"/>
         <source>Hash calculation:: %1</source>
         <comment>Info file</comment>
         <translation>Calculer valeurs hash:: %1</translation>
     </message>
     <message>
-        <location line="+534"/>
+        <location line="+521"/>
         <source>Aborted because of source read error</source>
         <comment>Info file</comment>
         <translation>Abandonné à cause d&apos;une erreur lors de la lecture du media source</translation>
     </message>
     <message>
-        <location line="+16"/>
+        <location line="+19"/>
         <source>Aborted, strange reason (%1 %2)</source>
         <comment>Info file</comment>
         <translation>Abandonné pour une raison inconnue (%1 %2)</translation>
     </message>
     <message>
-        <location line="+14"/>
+        <location line="+37"/>
         <source>SHA1 hash:: %1</source>
         <comment>Info file</comment>
         <translation>Hash SHA-1:: %1</translation>
@@ -1756,13 +1851,13 @@ Utilise libguytools %6</translation>
         <translation>Hash SHA-1 image vérifié:: %1</translation>
     </message>
     <message>
-        <location line="-594"/>
+        <location line="-607"/>
         <source>Hidden areas: %1</source>
         <comment>Info file</comment>
         <translation>Espaces cachés: %1</translation>
     </message>
     <message>
-        <location line="+712"/>
+        <location line="+725"/>
         <source>Acquisition/verification aborted - file list may be incomplete</source>
         <translation>Abandon de l&apos;acquisition / vérification - la liste de fichiers est probablement incomplète </translation>
     </message>
@@ -1770,7 +1865,7 @@ Utilise libguytools %6</translation>
 <context>
     <name>t_ThreadScan</name>
     <message>
-        <location filename="threadscan.cpp" line="+52"/>
+        <location filename="threadscan.cpp" line="+53"/>
         <source>Cannot scan devices</source>
         <comment>Dialog title</comment>
         <translation>Recherche médias échouée</translation>
