@@ -1,12 +1,12 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="nl">
+<TS version="2.1" language="nl">
 <context>
     <name>QObject</name>
     <message>
-        <location filename="dlgabort.cpp" line="+82"/>
-        <location filename="dlgacquire.cpp" line="+795"/>
-        <location filename="dlgdirsel.cpp" line="+100"/>
+        <location filename="dlgabort.cpp" line="+83"/>
+        <location filename="dlgacquire.cpp" line="+811"/>
+        <location filename="dlgdirsel.cpp" line="+106"/>
         <source>Ok</source>
         <translation>Ok</translation>
     </message>
@@ -24,7 +24,7 @@
         <translation>Linux dd &quot;raw&quot; image</translation>
     </message>
     <message>
-        <location line="+23"/>
+        <location line="+24"/>
         <source>Expert Witness Format, sub-format %1</source>
         <translation>Expert Witness Formaat, sub-formaat %1</translation>
     </message>
@@ -34,7 +34,7 @@
         <translation>Advanced forensic image</translation>
     </message>
     <message>
-        <location filename="main.cpp" line="+465"/>
+        <location filename="main.cpp" line="+508"/>
         <source>Missing root rights</source>
         <comment>Dialog title</comment>
         <translation>Root rechten benodigd</translation>
@@ -46,12 +46,12 @@ Continue anyway?</source>
         <translation>Guymager moet gestart worden met &quot;root&quot;-rechten om media veilig te kunnen stellen. U bent op dit moment geen &quot;root&quot;, en daarom zult u geen media veilig kunnen stellen.</translation>
     </message>
     <message>
-        <location filename="threadwrite.cpp" line="+1468"/>
+        <location filename="threadwrite.cpp" line="+1480"/>
         <source>Deleting %1</source>
         <translation>%1 aan het verwijderen</translation>
     </message>
     <message>
-        <location filename="threadscan.cpp" line="+1010"/>
+        <location filename="threadscan.cpp" line="+1440"/>
         <source>Guymager cannot scan the devices connected to this computer.</source>
         <translation>Guymager kan geen lijst samenstellen met aangesloten apparaten.</translation>
     </message>
@@ -71,7 +71,7 @@ Continue anyway?</source>
         <translation>Probeer methode &quot;%1&quot;</translation>
     </message>
     <message>
-        <location filename="file.cpp" line="-28"/>
+        <location filename="file.cpp" line="-29"/>
         <source>Creation of a clone</source>
         <translation>Maak een exacte kopie (&quot;Clone&quot;)</translation>
     </message>
@@ -158,12 +158,12 @@ usage
         <translation type="obsolete">FIFO Wachtrijen</translation>
     </message>
     <message>
-        <location line="-383"/>
+        <location line="-392"/>
         <source>Remark</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.h" line="+42"/>
+        <location filename="mainwindow.h" line="+47"/>
         <source>SerialNr</source>
         <translation type="unfinished"></translation>
     </message>
@@ -285,8 +285,8 @@ usage
 <context>
     <name>t_DlgAcquire</name>
     <message>
-        <location filename="config.h" line="+266"/>
-        <location filename="table.cpp" line="+309"/>
+        <location filename="config.h" line="+274"/>
+        <location filename="table.cpp" line="+345"/>
         <source>EwfCaseNumber</source>
         <translation>Zaaknummer</translation>
     </message>
@@ -335,13 +335,13 @@ usage
         <translation>Bestemmingsnaam voor info</translation>
     </message>
     <message>
-        <location filename="dlgacquire.cpp" line="-155"/>
+        <location filename="dlgacquire.cpp" line="-152"/>
         <source>...</source>
         <comment>The directory browse button</comment>
         <translation>...</translation>
     </message>
     <message>
-        <location line="+365"/>
+        <location line="+364"/>
         <source>File format</source>
         <translation>Bestandsformaat</translation>
     </message>
@@ -352,7 +352,7 @@ usage
         <translation>(Bestandsextensie %1)&gt;</translation>
     </message>
     <message>
-        <location line="+61"/>
+        <location line="+68"/>
         <source>Destination</source>
         <translation>Bestemming</translation>
     </message>
@@ -362,35 +362,34 @@ usage
         <translation>Configuratievlag WriteToDevNull is gezet!</translation>
     </message>
     <message>
-        <location line="+293"/>
+        <location line="+297"/>
         <source>Select destination directory</source>
         <comment>Dialog title</comment>
         <translation>Selecteer de bestemmingsmap</translation>
     </message>
     <message>
-        <location line="+222"/>
+        <location line="+265"/>
         <source>The split size for the configured EWF format must be in the range %1 - %2 MiB. For bigger files, switch to Encase6 format or Guymager (see Guymager configuration file, parameter EwfFormat).</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+39"/>
+        <location line="+44"/>
         <source>Special characters</source>
         <comment>Dialog title</comment>
         <translation>Speciale karakters</translation>
     </message>
     <message>
-        <location line="-5"/>
         <source>The filenames contain special characters which are not allowed. Guymager suggests the following changes:
 	Image filename: %1
 	Info filename: %2
 Do you accept these changes?</source>
-        <translation>De bestandsnamen bevatten speciale karakters die niet zijn toegestaan. Guymager suggereert de volgende wijzingen:
+        <translation type="vanished">De bestandsnamen bevatten speciale karakters die niet zijn toegestaan. Guymager suggereert de volgende wijzingen:
 	Image bestandsnaam: %1
 	Info bestandsnaam: %2
 Wilt u deze wijzigingen accepteren?</translation>
     </message>
     <message>
-        <location line="-109"/>
+        <location line="-117"/>
         <source>Access denied</source>
         <comment>Dialog title</comment>
         <translation>Toegang verboden</translation>
@@ -416,12 +415,12 @@ Wilt u deze wijzigingen accepteren?</translation>
         <translation>Vergelijk hash bestemming</translation>
     </message>
     <message>
-        <location filename="dlgacquire.cpp" line="-425"/>
+        <location filename="dlgacquire.cpp" line="-474"/>
         <source>Hash calculation / verification</source>
         <translation>Hash berekening / verificatie</translation>
     </message>
     <message>
-        <location line="+426"/>
+        <location line="+475"/>
         <source>Guymager cannot write to the directory
 	%1
 This may be due to insufficient access rights or unsupported filename characters. Please choose another directory.</source>
@@ -430,7 +429,7 @@ This may be due to insufficient access rights or unsupported filename characters
 Dit kan kan komen door onvoldoende rechten of niet-ondersteunde karakters in de bestandsnaam. Kies een andere map als bestemming.</translation>
     </message>
     <message>
-        <location line="-740"/>
+        <location line="-798"/>
         <source>Local device, cannot be written</source>
         <translation>Lokaal apparaat, kan niet geschreven worden</translation>
     </message>
@@ -450,16 +449,15 @@ Dit kan kan komen door onvoldoende rechten of niet-ondersteunde karakters in de
         <translation>Ok voor kloon</translation>
     </message>
     <message>
-        <location line="+837"/>
         <source>The info filename contains special characters which are not allowed. Guymager suggests the following changes:
 	%1
 Do you accept these changes?</source>
-        <translation>De bestandsnaam van het infobestand bevat speciala karakters die niet zijn toegestaan. Guymager suggereert de volgende wijzigingen:
+        <translation type="vanished">De bestandsnaam van het infobestand bevat speciala karakters die niet zijn toegestaan. Guymager suggereert de volgende wijzigingen:
 	%1
 Wilt u deze wijzigingen accepteren?</translation>
     </message>
     <message>
-        <location line="+95"/>
+        <location line="+1036"/>
         <source>Files exist</source>
         <comment>Dialog title</comment>
         <translation>Bestand bestaat reeds</translation>
@@ -470,7 +468,7 @@ Wilt u deze wijzigingen accepteren?</translation>
         <translation>Het image- of infobestand bestaat al. Overschrijven?</translation>
     </message>
     <message>
-        <location line="-777"/>
+        <location line="-881"/>
         <source>Clone %1</source>
         <comment>Dialog title, %1 is the device (for instance /dev/hdc)</comment>
         <translation>Kloon %1</translation>
@@ -502,12 +500,12 @@ Wilt u deze wijzigingen accepteren?</translation>
         <translation>Opsplitsen</translation>
     </message>
     <message>
-        <location filename="dlgacquire.cpp" line="+215"/>
+        <location filename="dlgacquire.cpp" line="+217"/>
         <source>(file extension %1 or %2)</source>
         <translation>(bestandsextensie %1 of %2)</translation>
     </message>
     <message>
-        <location line="+564"/>
+        <location line="+618"/>
         <location line="+15"/>
         <location line="+12"/>
         <source>Incorrect value</source>
@@ -520,7 +518,7 @@ Wilt u deze wijzigingen accepteren?</translation>
         <translation>De grootte van de delen van het bestand is niet correct. Alleen positieve getallen kunnen ingevoerd worden.</translation>
     </message>
     <message>
-        <location line="+154"/>
+        <location line="+202"/>
         <source>The info file already exists. Do you want to overwrite it?</source>
         <translation>Het infobestand bestaat al. Wilt u het overschrijven?</translation>
     </message>
@@ -539,7 +537,7 @@ Wilt u deze wijzigingen accepteren?</translation>
         <translation type="unfinished">Bereken SHA-1</translation>
     </message>
     <message>
-        <location filename="dlgacquire.cpp" line="-935"/>
+        <location filename="dlgacquire.cpp" line="-1039"/>
         <source>Selected for first acquisition</source>
         <translation type="unfinished"></translation>
     </message>
@@ -556,12 +554,12 @@ Wilt u deze wijzigingen accepteren?</translation>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+28"/>
+        <location line="+30"/>
         <source>Duplicate image settings</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+155"/>
+        <location line="+162"/>
         <location line="+21"/>
         <source>Back...</source>
         <translation type="unfinished"></translation>
@@ -573,12 +571,60 @@ Wilt u deze wijzigingen accepteren?</translation>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+430"/>
+        <location line="+356"/>
+        <source>Path not found</source>
+        <comment>Dialog title</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>The destination directory
+   %1
+doesn&apos;t exist. Do you want to create it?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+120"/>
         <source>The split size for the selected image format must be in the range %1MiB - %2EiB.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+81"/>
+        <location line="+49"/>
+        <source>The directory or file names contain special characters which are not allowed. Guymager suggests the following changes:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>
+   Image directory:	%1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>
+   Image filename:	%1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>
+   Info directory:	%1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>
+   Info filename:	%1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+2"/>
+        <source>
+Do you accept these changes?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+33"/>
         <source>Destination in use</source>
         <comment>Dialog title</comment>
         <translation type="unfinished"></translation>
@@ -600,7 +646,18 @@ Wilt u deze wijzigingen accepteren?</translation>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+76"/>
+        <location line="+52"/>
+        <source>Files already used</source>
+        <comment>Dialog title</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>The image or info files already are used in the acquisition of %1. Please chose different ones.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+64"/>
         <source>Large amount of segment files</source>
         <comment>Dialog title</comment>
         <translation type="unfinished"></translation>
@@ -630,7 +687,7 @@ Do you want to continue anyway?</source>
 <context>
     <name>t_DlgAutoExit</name>
     <message>
-        <location filename="dlgautoexit.cpp" line="+79"/>
+        <location filename="dlgautoexit.cpp" line="+85"/>
         <source>Abort</source>
         <translation type="unfinished">Afbreken</translation>
     </message>
@@ -674,7 +731,7 @@ Guymager will exit automatically in %1 seconds.</source>
 <context>
     <name>t_DlgMessage</name>
     <message>
-        <location filename="dlgmessage.cpp" line="+94"/>
+        <location filename="dlgmessage.cpp" line="+100"/>
         <source>Close</source>
         <translation>Sluiten</translation>
     </message>
@@ -682,7 +739,7 @@ Guymager will exit automatically in %1 seconds.</source>
 <context>
     <name>t_Info</name>
     <message>
-        <location filename="info.cpp" line="+200"/>
+        <location filename="info.cpp" line="+201"/>
         <source>Command executed: %1</source>
         <translation>Uitgevoerd commando: %1</translation>
     </message>
@@ -700,7 +757,7 @@ Guymager will exit automatically in %1 seconds.</source>
 <context>
     <name>t_InfoField</name>
     <message>
-        <location filename="infofield.cpp" line="+105"/>
+        <location filename="infofield.cpp" line="+109"/>
         <source>Size</source>
         <translation>Grootte</translation>
     </message>
@@ -808,7 +865,7 @@ Guymager will exit automatically in %1 seconds.</source>
 <context>
     <name>t_MainWindow</name>
     <message>
-        <location filename="device.cpp" line="+391"/>
+        <location filename="device.cpp" line="+398"/>
         <source>Local device</source>
         <translation>Lokaal apparaat</translation>
     </message>
@@ -863,7 +920,7 @@ Guymager will exit automatically in %1 seconds.</source>
         <translation type="obsolete">Afgebroken - Fout: Reden is &apos;geen&apos;</translation>
     </message>
     <message>
-        <location line="-353"/>
+        <location line="-355"/>
         <source>Aborted by user</source>
         <translation>Afgebroken door de gebruiker</translation>
     </message>
@@ -876,7 +933,7 @@ Guymager will exit automatically in %1 seconds.</source>
         <translation type="obsolete">Afgebroken - apparaat kan niet gelezen worden</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="+281"/>
+        <location filename="mainwindow.cpp" line="+291"/>
         <source>&amp;Rescan</source>
         <translation>&amp;Herscannen</translation>
     </message>
@@ -921,7 +978,13 @@ Guymager will exit automatically in %1 seconds.</source>
         <translation>Over &amp;Qt&gt;</translation>
     </message>
     <message>
-        <location line="+326"/>
+        <location line="+175"/>
+        <source>Device already contained</source>
+        <comment>Dialog title</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+154"/>
         <source>Exit GUYMAGER</source>
         <comment>Dialog title</comment>
         <translation>GUYMAGER Afsluiten</translation>
@@ -977,7 +1040,7 @@ Using libguytools %5</translation>
         <translation type="obsolete">Afgebroken - Image bestand verificatie fout</translation>
     </message>
     <message>
-        <location filename="device.cpp" line="+454"/>
+        <location filename="device.cpp" line="+456"/>
         <source>Unknown</source>
         <comment>Media info string for informing about hidden areas (HPA/DCO)</comment>
         <translation>Onbekend</translation>
@@ -995,7 +1058,7 @@ Using libguytools %5</translation>
         <translation>Ja</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="-431"/>
+        <location filename="mainwindow.cpp" line="-434"/>
         <source>Rescan devices and update table</source>
         <translation>Herscan de apparaten en ververs de tabel</translation>
     </message>
@@ -1006,7 +1069,7 @@ Using libguytools %5</translation>
         <translation>Voeg speciaal apparaat toe</translation>
     </message>
     <message>
-        <location line="+152"/>
+        <location line="+155"/>
         <source>Open File</source>
         <translation>Open bestand</translation>
     </message>
@@ -1023,13 +1086,12 @@ Using libguytools %5</translation>
         <translation>Handmatig toegevoegd speciaal apparaat</translation>
     </message>
     <message>
-        <location line="+6"/>
         <source>Device alrady contained</source>
         <comment>Dialog title</comment>
-        <translation>Apparaat reeds beschikbaar</translation>
+        <translation type="vanished">Apparaat reeds beschikbaar</translation>
     </message>
     <message>
-        <location line="+0"/>
+        <location line="+6"/>
         <source>The selected file or device already is contained in the table.</source>
         <translation>Het geselecteerde bestand of apparaat staat al in de tabel.</translation>
     </message>
@@ -1066,7 +1128,7 @@ Using libguytools %5</translation>
         <translation>onbekend</translation>
     </message>
     <message>
-        <location line="-466"/>
+        <location line="-468"/>
         <source>Acquisition start failure</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1131,7 +1193,7 @@ Using libguytools %5</translation>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+276"/>
+        <location line="+278"/>
         <source>Running</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1199,12 +1261,12 @@ Using libguytools %5</translation>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="-170"/>
+        <location filename="mainwindow.cpp" line="-173"/>
         <source>Exit after acquisitions completed</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+402"/>
+        <location line="+405"/>
         <source>(not used as Guymager currently is configured to use its own EWF module)</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1223,7 +1285,7 @@ Linked with libguytools %6</source>
 <context>
     <name>t_Table</name>
     <message>
-        <location filename="table.cpp" line="-202"/>
+        <location filename="table.cpp" line="-228"/>
         <source>Info</source>
         <comment>Context menu</comment>
         <translation>Informatie</translation>
@@ -1234,19 +1296,19 @@ Linked with libguytools %6</source>
         <translation>Lokaal apparaat - kan niet veiliggesteld worden</translation>
     </message>
     <message>
-        <location line="+100"/>
+        <location line="+111"/>
         <source>Device info</source>
         <comment>Dialog title</comment>
         <translation>Apparaat info</translation>
     </message>
     <message>
-        <location line="+21"/>
+        <location line="+26"/>
         <source>GUYMAGER ACQUISITION INFO FILE</source>
         <comment>Info file</comment>
         <translation>GUYMANAGER INFO BESTAND VEILIGSTELLEN</translation>
     </message>
     <message>
-        <location line="+6"/>
+        <location line="+13"/>
         <source>Guymager</source>
         <comment>Info file</comment>
         <translation>Info bestand</translation>
@@ -1281,6 +1343,24 @@ Linked with libguytools %6</source>
         <comment>Info file</comment>
         <translation>libguytools versie:: %1</translation>
     </message>
+    <message>
+        <location line="+1"/>
+        <source>Host name:: %1</source>
+        <comment>Info file</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Domain name:: %1</source>
+        <comment>Info file</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>System:: %1</source>
+        <comment>Info file</comment>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location line="+5"/>
         <source>Device information</source>
@@ -1317,7 +1397,7 @@ Linked with libguytools %6</source>
         <translation>Bron verificatie:: uit</translation>
     </message>
     <message>
-        <location line="+391"/>
+        <location line="+393"/>
         <source>During verification, %1 bad sectors have been encountered. The sector numbers are:</source>
         <comment>Info file</comment>
         <translation>Tijdens de verificatie zijn %1 bad sectors aangetroffen. De sectornummers zijn:</translation>
@@ -1341,13 +1421,13 @@ Linked with libguytools %6</source>
         <translation>Er zijn geen sectoren met fouten aangetroffen tijdens het veiligstellen.</translation>
     </message>
     <message>
-        <location line="+40"/>
+        <location line="+42"/>
         <source>--</source>
         <comment>Info file</comment>
         <translation>--</translation>
     </message>
     <message>
-        <location line="+8"/>
+        <location line="+55"/>
         <source>Finished successfully</source>
         <comment>Info file</comment>
         <translation>Met succes klaar</translation>
@@ -1359,7 +1439,7 @@ Linked with libguytools %6</source>
         <translation>(met %1 slechte sectoren)</translation>
     </message>
     <message>
-        <location line="+22"/>
+        <location line="-45"/>
         <source>Aborted by user</source>
         <comment>Info file</comment>
         <translation>Afgebroken door de gebruiker</translation>
@@ -1377,7 +1457,7 @@ Linked with libguytools %6</source>
         <translation>(tijdens verificatie van de bron)</translation>
     </message>
     <message>
-        <location line="+21"/>
+        <location line="+27"/>
         <source>Aborted because of image write error</source>
         <comment>Info file</comment>
         <translation>Afgebroken vanwege een fout bij wegschrijven</translation>
@@ -1388,13 +1468,13 @@ Linked with libguytools %6</source>
         <translation type="obsolete">Afgebroken met een vage reden (%1)</translation>
     </message>
     <message>
-        <location line="+8"/>
+        <location line="+30"/>
         <source>Strange state (%1)</source>
         <comment>Info file</comment>
         <translation>Onverwachte status (%1)</translation>
     </message>
     <message>
-        <location line="+2"/>
+        <location line="+3"/>
         <source>State: %1</source>
         <comment>Info file</comment>
         <translation>Status: %1</translation>
@@ -1470,7 +1550,7 @@ Linked with libguytools %6</source>
         <translation type="obsolete">Hash berekening:: SHA-256</translation>
     </message>
     <message>
-        <location line="-633"/>
+        <location line="-646"/>
         <source>Image path and file name:: %1</source>
         <comment>Info file</comment>
         <translation>Pad en bestandsnaam van imagebestand:: %1</translation>
@@ -1494,13 +1574,26 @@ Linked with libguytools %6</source>
         <translation>Image verificatie:: uit</translation>
     </message>
     <message>
-        <location line="+535"/>
+        <location line="+516"/>
+        <source>Aborted, too many bad sectors (&gt; %1)</source>
+        <comment>Info file</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+3"/>
+        <source>Aborted because device has been inaccessible for too long (&gt; %1s)</source>
+        <oldsource>Aborted because device has is inaccessible for too long (&gt; %1s)</oldsource>
+        <comment>Info file</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+6"/>
         <source>Aborted because of image read error during verification</source>
         <comment>Info file</comment>
         <translation>Afgebroken vanwege een leesfout van het imagebestand tijdens de verificatie</translation>
     </message>
     <message>
-        <location line="+19"/>
+        <location line="+42"/>
         <source>MD5 hash verified source:: %1</source>
         <comment>Info file</comment>
         <translation>MD5 hash geverifieerd van de bron:: %1</translation>
@@ -1549,13 +1642,13 @@ Linked with libguytools %6</source>
         <translation>U kunt proberen om het apparaat nogmaals veilig te stellen.</translation>
     </message>
     <message>
-        <location line="-800"/>
+        <location line="-839"/>
         <source>Remove special device</source>
         <comment>Context menu</comment>
         <translation>Verwijder speciaal apparaat</translation>
     </message>
     <message>
-        <location line="+196"/>
+        <location line="+222"/>
         <source>Image meta data</source>
         <comment>Info file</comment>
         <translation>Image meta data</translation>
@@ -1567,7 +1660,7 @@ Linked with libguytools %6</source>
         <translation> - Bestandsextensie is %1</translation>
     </message>
     <message>
-        <location line="-196"/>
+        <location line="-222"/>
         <source>Acquire image</source>
         <comment>Context menu</comment>
         <translation>Veiligstellen</translation>
@@ -1585,7 +1678,7 @@ Linked with libguytools %6</source>
         <translation>Afbreken</translation>
     </message>
     <message>
-        <location line="+186"/>
+        <location line="+212"/>
         <source>Acquisition</source>
         <comment>Info file</comment>
         <translation>Veiligstellen</translation>
@@ -1597,7 +1690,7 @@ Linked with libguytools %6</source>
         <translation>Formaat:: %1</translation>
     </message>
     <message>
-        <location line="-152"/>
+        <location line="-178"/>
         <source>Device used for cloning - cannot be acquired</source>
         <translation>Apparaat in gebruik voor klonen - kan niet veiliggesteld worden</translation>
     </message>
@@ -1607,7 +1700,7 @@ Linked with libguytools %6</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+141"/>
+        <location line="+167"/>
         <source>Hidden areas: %1</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
@@ -1619,19 +1712,19 @@ Linked with libguytools %6</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+534"/>
+        <location line="+521"/>
         <source>Aborted because of source read error</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+3"/>
+        <location line="-3"/>
         <source>Aborted because acquisition failed to start</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+12"/>
+        <location line="+21"/>
         <source>Aborted because of info file write error</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
@@ -1643,7 +1736,7 @@ Linked with libguytools %6</source>
         <translation type="unfinished">Afgebroken met een vage reden (%1) {1 %2)?}</translation>
     </message>
     <message>
-        <location line="+14"/>
+        <location line="+37"/>
         <source>SHA1 hash:: %1</source>
         <comment>Info file</comment>
         <translation type="unfinished">SHA-256 hash:: %1 {1 ?}</translation>
@@ -1690,7 +1783,7 @@ Linked with libguytools %6</source>
 <context>
     <name>t_ThreadScan</name>
     <message>
-        <location filename="threadscan.cpp" line="+52"/>
+        <location filename="threadscan.cpp" line="+53"/>
         <source>Cannot scan devices</source>
         <comment>Dialog title</comment>
         <translation>Kan apparaten niet scannen</translation>
