@@ -10,24 +10,28 @@
 //                  widget
 // ****************************************************************************
 
-// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014 Guy Voncken
+// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016 Guy Voncken
 //
-// This file is part of guymager.
+// This file is part of Guymager.
 //
-// guymager is free software: you can redistribute it and/or modify
+// Guymager is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation, either version 2 of the License, or
 // (at your option) any later version.
 //
-// guymager is distributed in the hope that it will be useful,
+// Guymager is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with guymager. If not, see <http://www.gnu.org/licenses/>.
+// along with Guymager. If not, see <http://www.gnu.org/licenses/>.
 
-#include <QtGui>
+#if (QT_VERSION >= 0x050000)
+   #include <QtWidgets> //lint !e537 Repeated include
+#else
+   #include <QtGui>     //lint !e537 Repeated include
+#endif
 
 #include "common.h"
 
@@ -154,9 +158,15 @@ void t_DeviceListModel::SlotRefresh (void)
    static int LastCount=0;
 
    if (poDeviceList->count() != LastCount)
-        reset();
-   else emit dataChanged (index(0,0), index(rowCount()-1, columnCount()-1) );
-   LastCount = poDeviceList->count();
+   {
+      QAbstractTableModel::beginResetModel();
+      QAbstractTableModel::endResetModel();
+      LastCount = poDeviceList->count();
+   }
+   else
+   {
+      emit dataChanged (index(0,0), index(rowCount()-1, columnCount()-1) );
+   }
 }
 
 //void t_DeviceListModel::SlotUpdate (void)
@@ -317,10 +327,11 @@ t_MainWindow::t_MainWindow(void)
    CHK_EXIT (ERROR_MAINWINDOW_CONSTRUCTOR_NOT_SUPPORTED)
 } //lint !e1401 pOwn not initialised
 
-t_MainWindow::t_MainWindow (t_pDeviceList pDeviceList, QWidget *pParent, Qt::WFlags Flags)
+t_MainWindow::t_MainWindow (t_pDeviceList pDeviceList, QWidget *pParent, Qt::WindowFlags Flags)
    :QMainWindow (pParent, Flags)
 {
    static bool Initialised = false;
+   QString     Version;
 
    if (!Initialised)
    {
@@ -335,7 +346,9 @@ t_MainWindow::t_MainWindow (t_pDeviceList pDeviceList, QWidget *pParent, Qt::WFl
    pOwn->pRunStats        = new t_RunStats (pDeviceList);
 
    CHK_EXIT (CreateMenu ())
-   setWindowTitle ("GUYMAGER");
+
+   Version = QString(pCompileInfoVersion).split(QRegExp("beta|-"))[0]; // Only take the main part of the version number
+   setWindowTitle (QString ("GUYMAGER %1") .arg(Version));
 //   setSizeGripEnabled (true);
 
    // Create models and view according do the following layering:
@@ -347,9 +360,9 @@ t_MainWindow::t_MainWindow (t_pDeviceList pDeviceList, QWidget *pParent, Qt::WFl
    pOwn->pCentralWidget = new QWidget (this);
    QVBoxLayout *pLayout = new QVBoxLayout (pOwn->pCentralWidget);
 
-   pOwn->pTable                      = new t_Table (pOwn->pCentralWidget, this, pDeviceList);
-   pOwn->pDeviceListModel            = new t_DeviceListModel (pDeviceList);
-   pOwn->pProxyModel                 = new QSortFilterProxyModel (pOwn->pCentralWidget);
+   pOwn->pTable           = new t_Table (pOwn->pCentralWidget, this, pDeviceList);
+   pOwn->pDeviceListModel = new t_DeviceListModel (pDeviceList);
+   pOwn->pProxyModel      = new QSortFilterProxyModel (pOwn->pCentralWidget);
    pOwn->pProxyModel->setSourceModel (pOwn->pDeviceListModel);
    pOwn->pTable     ->setModel       (pOwn->pProxyModel);
 
@@ -359,8 +372,8 @@ t_MainWindow::t_MainWindow (t_pDeviceList pDeviceList, QWidget *pParent, Qt::WFl
    pLayout->addWidget (pOwn->pInfoField);
 
    CHK_QT_EXIT (connect (pOwn->pTable->horizontalHeader(), SIGNAL(sectionClicked            (int      )), pOwn->pTable    , SLOT(sortByColumn  (int      ))))
-   CHK_QT_EXIT (connect (pOwn->pTable                    , SIGNAL(SignalDeviceSelected      (t_pDevice)), pOwn->pInfoField, SLOT (SlotShowInfo (t_pDevice))))
-   CHK_QT_EXIT (connect (pOwn->pTable                    , SIGNAL(SignalAllAcquisitionsEnded(void     )), this            , SLOT (SlotAutoExit (void     ))))
+   CHK_QT_EXIT (connect (pOwn->pTable                    , SIGNAL(SignalDeviceSelected      (t_pDevice)), pOwn->pInfoField, SLOT(SlotShowInfo  (t_pDevice))))
+   CHK_QT_EXIT (connect (pOwn->pTable                    , SIGNAL(SignalAllAcquisitionsEnded(void     )), this            , SLOT(SlotAutoExit  (void     ))))
 
    setCentralWidget (pOwn->pCentralWidget);
 
@@ -471,7 +484,7 @@ void t_MainWindow::SlotAddSpecialDevice (void)
       if (pDeviceFound)
       {
          delete pDevice;
-         t_MessageBox::information (this, tr ("Device alrady contained", "Dialog title"), tr("The selected file or device already is contained in the table."), QMessageBox::Ok);
+         t_MessageBox::information (this, tr ("Device already contained", "Dialog title"), tr("The selected file or device already is contained in the table."), QMessageBox::Ok);
          continue;
       }
       break;
