@@ -7,31 +7,36 @@
 //                  Section Nouvelles Technologies
 // ****************************************************************************
 
-// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014 Guy Voncken
+// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016 Guy Voncken
 //
-// This file is part of guymager.
+// This file is part of Guymager.
 //
-// guymager is free software: you can redistribute it and/or modify
+// Guymager is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation, either version 2 of the License, or
 // (at your option) any later version.
 //
-// guymager is distributed in the hope that it will be useful,
+// Guymager is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with guymager. If not, see <http://www.gnu.org/licenses/>.
+// along with Guymager. If not, see <http://www.gnu.org/licenses/>.
 
 #ifndef __MAINWINDOW_H__
 #define __MAINWINDOW_H__
 
-#include <QtGui>  //lint !e537 repeated include
-
 #ifndef __COMMON_H__
    #include "common.h"
 #endif
+
+#if (QT_VERSION >= 0x050000)
+   #include <QtWidgets> //lint !e537 Repeated include
+#else
+   #include <QtGui>     //lint !e537 Repeated include
+#endif
+
 #ifndef __DEVICE_H__
    #include "device.h"
 #endif
@@ -71,7 +76,7 @@ class t_MainWindow: public QMainWindow
 
    public:
       t_MainWindow (void);
-      t_MainWindow (t_pDeviceList pDeviceList, QWidget *pParent = 0, Qt::WFlags Flags = 0);
+      t_MainWindow (t_pDeviceList pDeviceList, QWidget *pParent = 0, Qt::WindowFlags Flags = 0);
      ~t_MainWindow ();
 
    APIRET RemoveSpecialDevice (t_pDevice pDevice);
