@@ -9,28 +9,32 @@
 //  Module:         The table widget (central widget of the application)
 // ****************************************************************************
 
-// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014 Guy Voncken
+// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016 Guy Voncken
 //
-// This file is part of guymager.
+// This file is part of Guymager.
 //
-// guymager is free software: you can redistribute it and/or modify
+// Guymager is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation, either version 2 of the License, or
 // (at your option) any later version.
 //
-// guymager is distributed in the hope that it will be useful,
+// Guymager is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with guymager. If not, see <http://www.gnu.org/licenses/>.
-//
+// along with Guymager. If not, see <http://www.gnu.org/licenses/>.
+
 // Since version 0.7.x, Guymager includes the JobQueue feature. The idea and
 // initial source code for this are a contribution of Erwin van Eijk.
 
 #include <unistd.h>
-#include <QtGui>
+#if (QT_VERSION >= 0x050000)
+   #include <QtWidgets> //lint !e537 Repeated include
+#else
+   #include <QtGui>     //lint !e537 Repeated include
+#endif
 
 #include "common.h"
 #include "config.h"
@@ -92,7 +96,6 @@ t_Table::t_Table (QWidget *pParent, t_MainWindow *pMainWindow, t_pDeviceList pDe
    CHK_EXIT (TOOL_ERROR_REGISTER_CODE (ERROR_TABLE_INVALID_DIALOG_CODE           ))
    CHK_EXIT (TOOL_ERROR_REGISTER_CODE (ERROR_TABLE_INVALID_FREE_HANDLE           ))
 
-
    setItemDelegate      (new t_ItemDelegate (this));
    setSelectionBehavior (QAbstractItemView::SelectRows     );
    setSelectionMode     (QAbstractItemView::SingleSelection);
@@ -102,8 +105,12 @@ t_Table::t_Table (QWidget *pParent, t_MainWindow *pMainWindow, t_pDeviceList pDe
    pOwn->pMainWindow          = pMainWindow;
    pOwn->SlowDownAcquisitions = false;
 
-   verticalHeader  ()->hide                  ();
-   horizontalHeader()->setClickable          (true);
+   verticalHeader()->hide();
+   #if (QT_VERSION >= 0x050000)
+      horizontalHeader()->setSectionsClickable  (true);
+   #else
+      horizontalHeader()->setClickable          (true);
+   #endif
    horizontalHeader()->setSortIndicatorShown (true);
    setHorizontalScrollMode (QAbstractItemView::ScrollPerPixel);
    setVerticalScrollMode   (QAbstractItemView::ScrollPerPixel);
@@ -114,7 +121,7 @@ t_Table::t_Table (QWidget *pParent, t_MainWindow *pMainWindow, t_pDeviceList pDe
    pOwn->pActionDeviceInfo          = new QAction(tr("Info"                 , "Context menu"), this);  addAction (pOwn->pActionDeviceInfo         );
    pOwn->pActionRemoveSpecialDevice = new QAction(tr("Remove special device", "Context menu"), this);  addAction (pOwn->pActionRemoveSpecialDevice);
 
-   CHK_QT_EXIT (connect (this, SIGNAL(clicked (const QModelIndex &)), this, SLOT(SlotMouseClick(const QModelIndex &))))
+   CHK_QT_EXIT (connect (this, SIGNAL(clicked(const QModelIndex &)), this, SLOT(SlotMouseClick(const QModelIndex &))))
 
 //   pOwn->pTable->setContextMenuPolicy (Qt::ActionsContextMenu);
 }
@@ -146,7 +153,7 @@ APIRET t_Table::GetDeviceUnderCursor (t_pDevice &pDevice)
    return NO_ERROR;
 }
 
-void t_Table::contextMenuEvent (QContextMenuEvent *pEvent)
+APIRET t_Table::ContextMenu (const QPoint &GlobalPos)
 {
    QAction     *pAction;
    QAction       LocalIndicator        (tr("Local Device - cannot be acquired"                   ), this);
@@ -162,7 +169,7 @@ void t_Table::contextMenuEvent (QContextMenuEvent *pEvent)
 
    QTUTIL_SET_FONT (&Menu, FONTOBJECT_MENU)
 
-   Pos = mapFromGlobal (pEvent->globalPos());           // The event coordinates are absolute screen coordinates, map them withb this widget
+   Pos = mapFromGlobal (GlobalPos);                     // The event coordinates are absolute screen coordinates, map them withb this widget
    CorrectedY = Pos.y() - horizontalHeader()->height(); // QTableView::rowAt seems to have a bug: It doesn't include the header height in the calculations. So, we correct it here.
    Pos.setY (CorrectedY);
 
@@ -171,10 +178,10 @@ void t_Table::contextMenuEvent (QContextMenuEvent *pEvent)
    Row = model()->data(Index, t_ItemDelegate::RowNrRole).toInt();
 
    if ((Row < 0) || (Row >= pOwn->pDeviceList->count())) // User clicked in the empty area
-      return;
+      return NO_ERROR;
 
    pDevice = pOwn->pDeviceList->at(Row);
-//   LOG_INFO ("Context global %d -- widget %d -- corrected %d -- index %d", pEvent->globalPos().y(), Pos.y(), CorrectedY, RowIndex);
+//   LOG_INFO ("Context global %d -- widget %d -- corrected %d -- index %d", GlobalPos.y(), Pos.y(), CorrectedY, RowIndex);
 
    RunningOrQueued = pDevice->pThreadRead   ||  pDevice->pThreadWrite1 ||
                      pDevice->pThreadWrite2 || (pDevice->GetState()==t_Device::Queued);
@@ -216,7 +223,7 @@ void t_Table::contextMenuEvent (QContextMenuEvent *pEvent)
    }
 
 //   StartRc = NO_ERROR;
-   pAction = Menu.exec (pEvent->globalPos());
+   pAction = Menu.exec (GlobalPos);
    if      (pAction == pOwn->pActionAcquire            ) CHK_EXIT (ShowAcquisitionDialog (pDevice, false))
    else if (pAction == pOwn->pActionClone              ) CHK_EXIT (ShowAcquisitionDialog (pDevice, true ))
    else if (pAction == pOwn->pActionAbort              ) CHK_EXIT (AbortAcquisition      (pDevice))
@@ -229,6 +236,17 @@ void t_Table::contextMenuEvent (QContextMenuEvent *pEvent)
 
 //   if (StartRc != NO_ERROR)
 //      pDevice->Error.Set(t_Device::t_Error::AcquisitionStartFailed);
+   return NO_ERROR;
+}
+
+void t_Table::contextMenuEvent (QContextMenuEvent *pEvent)
+{
+   CHK_EXIT (ContextMenu (pEvent->globalPos()))
+}
+
+void t_Table::mouseDoubleClickEvent (QMouseEvent *pEvent)
+{
+   CHK_EXIT (ContextMenu (pEvent->globalPos()))
 }
 
 void t_Table::SlotMouseClick (const QModelIndex & Index)
@@ -396,7 +414,9 @@ APIRET TableFifoCalcSizeAndAlloc (t_pDevice pDevice, unsigned int Fifos, unsigne
    // Calc the amount of memory for the blocks and allocate it
    // --------------------------------------------------------
    MaxBlocksInUse = pDevice->FifoMaxBlocks * Fifos;  // Data in the FIFOs
-   MaxBlocksInUse += 1;                              // ThreadRead might allocate an additional block that can't yet be written to the full FIFO
+   if (pDevice->Duplicate)
+        MaxBlocksInUse += 2;                         // ThreadRead might allocate an additional block that
+   else MaxBlocksInUse += 1;                         // can't yet be written to the full FIFO(s)
    if ((pDevice->Acquisition1.Format == t_File::AAFF) && !pDevice->HasCompressionThreads())
       MaxBlocksInUse += 1;                           // ThreadWrite might use an additional buffer if it does the AFF preprocessing
    if (pDevice->HasCompressionThreads())
@@ -430,7 +450,7 @@ APIRET t_Table::ShowAcquisitionDialog (t_pDevice pDevice, bool Clone)
             case t_DlgAcquire::ButtonDuplicate:
                CHK (Dlg.GetParameters (Acquisition1))
                {
-                  t_DlgAcquire DlgDuplicate (pDevice, Clone, pOwn->pDeviceList, true, this, 0, ForceLastEnteredValues);
+                  t_DlgAcquire DlgDuplicate (pDevice, Clone, pOwn->pDeviceList, true, this, 0, ForceLastEnteredValues, &Acquisition1);
                   DlgRc = DlgDuplicate.exec();
                   switch (DlgRc)
                   {
@@ -798,25 +818,27 @@ static APIRET TableTimestampToISO (const QDateTime &Timestamp, QString &Str)
 
 APIRET t_Table::InfoAcquisitionEnd0 (t_pAcquisition pAcquisition)
 {
-   t_pDevice pDevice = pAcquisition->pDevice;
-   QString    None;
-   QString    MD5;
-   QString    MD5VerifySrc;
-   QString    MD5VerifyDst;
-   QString    SHA1;
-   QString    SHA1VerifySrc;
-   QString    SHA1VerifyDst;
-   QString    SHA256;
-   QString    SHA256VerifySrc;
-   QString    SHA256VerifyDst;
-   QString    StateStr;
-   quint64    BadSectors;
-   QString    StartStr, StopStr, VerifyStr;
-   QString    Filename;
-   int        Hours, Minutes, Seconds;
-   double     Speed;
-   bool       MatchSrc = true;
-   bool       MatchDst = true;
+   t_pDevice        pDevice = pAcquisition->pDevice;
+   QString           None;
+   QString           MD5;
+   QString           MD5VerifySrc;
+   QString           MD5VerifyDst;
+   QString           SHA1;
+   QString           SHA1VerifySrc;
+   QString           SHA1VerifyDst;
+   QString           SHA256;
+   QString           SHA256VerifySrc;
+   QString           SHA256VerifyDst;
+   QString           StateStr;
+   quint64           BadSectors;
+   QString           StartStr, StopStr, VerifyStr;
+   QString           Filename;
+   int               Hours, Minutes, Seconds;
+   double            Speed;
+   bool              MatchSrc = true;
+   bool              MatchDst = true;
+   t_Device::t_State DeviceState;
+   uint              InstanceError;
 
    CHK (pAcquisition->Info.WriteLn ())
    CHK (InfoAcquisitionBadSectors (pAcquisition, false))
@@ -827,78 +849,81 @@ APIRET t_Table::InfoAcquisitionEnd0 (t_pAcquisition pAcquisition)
    MD5VerifySrc = None;     SHA1VerifySrc = None;   SHA256VerifySrc = None;
    MD5VerifyDst = None;     SHA1VerifyDst = None;   SHA256VerifyDst = None;
 
-   switch (pDevice->GetState())
+   DeviceState   = pDevice->GetState();                                                       // In case of duplicate acquisitions, this function is called for
+   InstanceError = pDevice->Error.Get(pAcquisition->Instance);                                // each acquisition separately in order to procuce separate info files.
+   if ( (DeviceState == t_Device::Aborted ) ||                                                // We therefore not only must respect the general acquisition state, but
+       ((DeviceState == t_Device::Finished) && (InstanceError != t_Device::t_Error::None)))   // also the individual instances.
    {
-      case t_Device::Finished:
-         StateStr = tr("Finished successfully", "Info file");
-         BadSectors = t_Device::GetBadSectorCount(pDevice).toULongLong();
-         if (BadSectors)
-            StateStr += " " + tr("(with %1 bad sectors)", "Info file, may be appended to 'finished successfully' message") .arg(BadSectors);
-         if (pAcquisition->CalcMD5   ) CHK (HashMD5DigestStr    (&pDevice->MD5Digest   , MD5   ))
-         if (pAcquisition->CalcSHA1  ) CHK (HashSHA1DigestStr   (&pDevice->SHA1Digest  , SHA1  ))
-         if (pAcquisition->CalcSHA256) CHK (HashSHA256DigestStr (&pDevice->SHA256Digest, SHA256))
-         if (pAcquisition->VerifySrc)
-         {
-            if (pAcquisition->CalcMD5   ) CHK (HashMD5DigestStr    (&pDevice->MD5DigestVerifySrc   , MD5VerifySrc   ))
-            if (pAcquisition->CalcSHA1  ) CHK (HashSHA1DigestStr   (&pDevice->SHA1DigestVerifySrc  , SHA1VerifySrc  ))
-            if (pAcquisition->CalcSHA256) CHK (HashSHA256DigestStr (&pDevice->SHA256DigestVerifySrc, SHA256VerifySrc))
-         }
-         if (pAcquisition->VerifyDst)
-         {
-            if (pAcquisition->CalcMD5   ) CHK (HashMD5DigestStr    (&pAcquisition->MD5DigestVerifyDst   , MD5VerifyDst   ))
-            if (pAcquisition->CalcSHA1  ) CHK (HashSHA1DigestStr   (&pAcquisition->SHA1DigestVerifyDst  , SHA1VerifyDst  ))
-            if (pAcquisition->CalcSHA256) CHK (HashSHA256DigestStr (&pAcquisition->SHA256DigestVerifyDst, SHA256VerifyDst))
-         }
-         break;
-
-      case t_Device::Aborted:
-         switch (pDevice->Error.Get())
-         {
-            case t_Device::t_Error::UserRequest:
-               StateStr = tr("Aborted by user", "Info file") + " ";
-               if (pDevice->StartTimestampVerify.isNull())
-               {
-                  StateStr += tr("(during acquisition)"     , "Info file");
-               }
-               else
-               {
-                  StateStr += tr("(during source verification)", "Info file");
-                  if (pAcquisition->CalcMD5   ) CHK (HashMD5DigestStr    (&pDevice->MD5Digest   , MD5   )) // If the user interrupted during
-                  if (pAcquisition->CalcSHA1  ) CHK (HashSHA1DigestStr   (&pDevice->SHA1Digest  , SHA1  )) // verification (i.e. after acquisition),
-                  if (pAcquisition->CalcSHA256) CHK (HashSHA256DigestStr (&pDevice->SHA256Digest, SHA256)) // we can calculate the acquisition hash.
-               }
-               break;
-            case t_Device::t_Error::AcquisitionStartFailed:
-               StateStr = tr("Aborted because acquisition failed to start", "Info file");
-               break;
-            case t_Device::t_Error::ReadError:
-               StateStr = tr("Aborted because of source read error", "Info file");
-               break;
-            case t_Device::t_Error::TooManyBadSectors:
-               StateStr = tr("Aborted, too many bad sectors (> %1)", "Info file") .arg(CONFIG(JobMaxBadSectors));
-               break;
-            case t_Device::t_Error::DisconnectTimeout:
-               StateStr = tr("Aborted because device has is inaccessible for too long (> %1s)", "Info file") .arg (CONFIG(JobDisconnectTimeout));
-               break;
-            default:
-               switch (pDevice->Error.Get (pAcquisition->Instance))
-               {
-                  case t_Device::t_Error::VerifyError:
-                     StateStr = tr("Aborted because of image read error during verification", "Info file");
-                     if (pAcquisition->CalcMD5   ) CHK (HashMD5DigestStr    (&pDevice->MD5Digest   , MD5   ))
-                     if (pAcquisition->CalcSHA1  ) CHK (HashSHA1DigestStr   (&pDevice->SHA1Digest  , SHA1  ))
-                     if (pAcquisition->CalcSHA256) CHK (HashSHA256DigestStr (&pDevice->SHA256Digest, SHA256))
-                     break;
-                  case t_Device::t_Error::WriteError : StateStr = tr("Aborted because of image write error"       , "Info file"); break;
-                  case t_Device::t_Error::InfoError  : StateStr = tr("Aborted because of info file write error"   , "Info file"); break;
-                  default:                             StateStr = tr("Aborted, strange reason (%1 %2)"            , "Info file") .arg(pDevice->Error.Get()) .arg(pDevice->Error.Get(pAcquisition->Instance)); break;
-               }
-         }
-         break;
-
-      default:
-         StateStr = tr("Strange state (%1)", "Info file") .arg(pDevice->GetState());
+      switch (pDevice->Error.Get())
+      {
+         case t_Device::t_Error::UserRequest:
+            StateStr = tr("Aborted by user", "Info file") + " ";
+            if (pDevice->StartTimestampVerify.isNull())
+            {
+               StateStr += tr("(during acquisition)"     , "Info file");
+            }
+            else
+            {
+               StateStr += tr("(during source verification)", "Info file");
+               if (pAcquisition->CalcMD5   ) CHK (HashMD5DigestStr    (&pDevice->MD5Digest   , MD5   )) // If the user interrupted during
+               if (pAcquisition->CalcSHA1  ) CHK (HashSHA1DigestStr   (&pDevice->SHA1Digest  , SHA1  )) // verification (i.e. after acquisition),
+               if (pAcquisition->CalcSHA256) CHK (HashSHA256DigestStr (&pDevice->SHA256Digest, SHA256)) // we can calculate the acquisition hash.
+            }
+            break;
+         case t_Device::t_Error::AcquisitionStartFailed:
+            StateStr = tr("Aborted because acquisition failed to start", "Info file");
+            break;
+         case t_Device::t_Error::ReadError:
+            StateStr = tr("Aborted because of source read error", "Info file");
+            break;
+         case t_Device::t_Error::TooManyBadSectors:
+            StateStr = tr("Aborted, too many bad sectors (> %1)", "Info file") .arg(CONFIG(JobMaxBadSectors));
+            break;
+         case t_Device::t_Error::DisconnectTimeout:
+            StateStr = tr("Aborted because device has been inaccessible for too long (> %1s)", "Info file") .arg (CONFIG(JobDisconnectTimeout));
+            break;
+         default:
+            switch (InstanceError)
+            {
+               case t_Device::t_Error::VerifyError:
+                  StateStr = tr("Aborted because of image read error during verification", "Info file");
+                  if (pAcquisition->CalcMD5   ) CHK (HashMD5DigestStr    (&pDevice->MD5Digest   , MD5   ))
+                  if (pAcquisition->CalcSHA1  ) CHK (HashSHA1DigestStr   (&pDevice->SHA1Digest  , SHA1  ))
+                  if (pAcquisition->CalcSHA256) CHK (HashSHA256DigestStr (&pDevice->SHA256Digest, SHA256))
+                  break;
+               case t_Device::t_Error::WriteError : StateStr = tr("Aborted because of image write error"       , "Info file"); break;
+               case t_Device::t_Error::InfoError  : StateStr = tr("Aborted because of info file write error"   , "Info file"); break;
+               default:                             StateStr = tr("Aborted, strange reason (%1 %2)"            , "Info file") .arg(pDevice->Error.Get()) .arg(pDevice->Error.Get(pAcquisition->Instance)); break;
+            }
+      }
    }
+   else if (DeviceState == t_Device::Finished)
+   {
+      StateStr = tr("Finished successfully", "Info file");
+      BadSectors = t_Device::GetBadSectorCount(pDevice).toULongLong();
+      if (BadSectors)
+         StateStr += " " + tr("(with %1 bad sectors)", "Info file, may be appended to 'finished successfully' message") .arg(BadSectors);
+      if (pAcquisition->CalcMD5   ) CHK (HashMD5DigestStr    (&pDevice->MD5Digest   , MD5   ))
+      if (pAcquisition->CalcSHA1  ) CHK (HashSHA1DigestStr   (&pDevice->SHA1Digest  , SHA1  ))
+      if (pAcquisition->CalcSHA256) CHK (HashSHA256DigestStr (&pDevice->SHA256Digest, SHA256))
+      if (pAcquisition->VerifySrc)
+      {
+         if (pAcquisition->CalcMD5   ) CHK (HashMD5DigestStr    (&pDevice->MD5DigestVerifySrc   , MD5VerifySrc   ))
+         if (pAcquisition->CalcSHA1  ) CHK (HashSHA1DigestStr   (&pDevice->SHA1DigestVerifySrc  , SHA1VerifySrc  ))
+         if (pAcquisition->CalcSHA256) CHK (HashSHA256DigestStr (&pDevice->SHA256DigestVerifySrc, SHA256VerifySrc))
+      }
+      if (pAcquisition->VerifyDst)
+      {
+         if (pAcquisition->CalcMD5   ) CHK (HashMD5DigestStr    (&pAcquisition->MD5DigestVerifyDst   , MD5VerifyDst   ))
+         if (pAcquisition->CalcSHA1  ) CHK (HashSHA1DigestStr   (&pAcquisition->SHA1DigestVerifyDst  , SHA1VerifyDst  ))
+         if (pAcquisition->CalcSHA256) CHK (HashSHA256DigestStr (&pAcquisition->SHA256DigestVerifyDst, SHA256VerifyDst))
+      }
+   }
+   else
+   {
+      StateStr = tr("Strange state (%1)", "Info file") .arg(pDevice->GetState());
+   }
+
    CHK (pAcquisition->Info.WriteLn (tr("State: %1", "Info file") .arg(StateStr)))
    CHK (pAcquisition->Info.WriteLn ())
 
@@ -1155,8 +1180,8 @@ APIRET t_Table::FinaliseThreadStructs (t_pDevice pDevice)
       // ----------------------------------------
       CHK (RescheduleJobs())
 
-      // Check if all acqusitions have completed now (for AutoExit)
-      // ----------------------------------------------------------
+      // Check if all acquisitions have completed now (for AutoExit)
+      // -----------------------------------------------------------
       t_Device::t_State State;
       int     i;
       bool    AllCompleted = true;
