@@ -9,22 +9,22 @@
 //  Module:         Thread for writing data.
 // ****************************************************************************
 
-// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014 Guy Voncken
+// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016 Guy Voncken
 //
-// This file is part of guymager.
+// This file is part of Guymager.
 //
-// guymager is free software: you can redistribute it and/or modify
+// Guymager is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation, either version 2 of the License, or
 // (at your option) any later version.
 //
-// guymager is distributed in the hope that it will be useful,
+// Guymager is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with guymager. If not, see <http://www.gnu.org/licenses/>.
+// along with Guymager. If not, see <http://www.gnu.org/licenses/>.
 
 #include "common.h"
 #include "compileinfo.h"
@@ -386,7 +386,7 @@ class t_OutputFileEWF: public t_OutputFile
          QString          GuymagerVersion;
          LIBEWF_HANDLE  *pFile=NULL;
          char           *pAsciiFileName;
-         QByteArray       AsciiFileName = (pAcquisition->ImagePath + pAcquisition->ImageFilename).toAscii();
+         QByteArray       AsciiFileName = (pAcquisition->ImagePath + pAcquisition->ImageFilename).toLatin1();
 
          poAcquisition          = pAcquisition;
          poDevice               = pAcquisition->pDevice;
@@ -416,7 +416,7 @@ class t_OutputFileEWF: public t_OutputFile
             for (i=0; i<oImageFileCount; i++)
             {
                FileInfo       = FileInfoList.takeFirst();
-               AsciiFileName  = FileInfo.absoluteFilePath().toAscii();
+               AsciiFileName  = FileInfo.absoluteFilePath().toLatin1();
                pAsciiFileName = AsciiFileName.data();
                poImageFilenameArr[i] = (char *) malloc (strlen(pAsciiFileName)+1);
                strcpy (poImageFilenameArr[i], pAsciiFileName);
@@ -489,7 +489,7 @@ class t_OutputFileEWF: public t_OutputFile
                SET_UTF8_STRING("acquiry_operating_system", Uname                        )
                SET_UTF8_STRING("acquiry_software_version", GuymagerVersion              )
             #else
-               #define MOD_QSTR(QStr) QStr.toAscii().data(), strlen(QStr.toAscii().data())
+               #define MOD_QSTR(QStr) QStr.toLatin1().data(), strlen(QStr.toLatin1().data())
                CHK_LIBEWF (libewf_set_format             (pFile, (uint8_t) CONFIG (EwfFormat)))
                CHK_LIBEWF (libewf_set_media_size         (pFile, poDevice->Size))
                CHK_LIBEWF (libewf_set_bytes_per_sector   (pFile, (unsigned int) poDevice->SectorSize))
@@ -645,14 +645,26 @@ class t_OutputFileEWF: public t_OutputFile
 
          // Write hash
          // ----------
-         if (!oVerification && poDevice->HasCompressionThreads() && poAcquisition->CalcMD5)
+         if (!oVerification && poDevice->HasCompressionThreads())
          {
-            #if (LIBEWF_VERSION >= 20130416)
-               CHK_LIBEWF (libewf_handle_set_md5_hash (poFile, (uint8_t*)&poDevice->MD5Digest, HASH_MD5_DIGEST_LENGTH, NULL))
-            #else
-               CHK_LIBEWF (libewf_set_md5_hash (poFile, (uint8_t*)&poDevice->MD5Digest, HASH_MD5_DIGEST_LENGTH))
-            #endif
+            if (poAcquisition->CalcMD5)
+            {
+               #if (LIBEWF_VERSION >= 20130416)
+                  CHK_LIBEWF (libewf_handle_set_md5_hash (poFile, (uint8_t*)&poDevice->MD5Digest, HASH_MD5_DIGEST_LENGTH, NULL))
+               #else
+                  CHK_LIBEWF (libewf_set_md5_hash (poFile, (uint8_t*)&poDevice->MD5Digest, HASH_MD5_DIGEST_LENGTH))
+               #endif
+            }
+            if (poAcquisition->CalcSHA1)
+            {
+               #if (LIBEWF_VERSION >= 20130416)
+                  CHK_LIBEWF (libewf_handle_set_sha1_hash (poFile, (uint8_t*)&poDevice->SHA1Digest, HASH_SHA1_DIGEST_LENGTH, NULL))
+               #else
+                  CHK_LIBEWF (libewf_set_sha1_hash (poFile, (uint8_t*)&poDevice->SHA1Digest, HASH_SHA1_DIGEST_LENGTH))
+               #endif
+            }
          }
+
          // Close and cleanup
          // -----------------
          #if (LIBEWF_VERSION >= 20130416)
