@@ -9,28 +9,34 @@
 //  Module:         Different utility functions
 // ****************************************************************************
 
-// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014 Guy Voncken
+// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016 Guy Voncken
 //
-// This file is part of guymager.
+// This file is part of Guymager.
 //
-// guymager is free software: you can redistribute it and/or modify
+// Guymager is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation, either version 2 of the License, or
 // (at your option) any later version.
 //
-// guymager is distributed in the hope that it will be useful,
+// Guymager is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with guymager. If not, see <http://www.gnu.org/licenses/>.
+// along with Guymager. If not, see <http://www.gnu.org/licenses/>.
 
 #include "common.h"
 
 #include <unistd.h>
+#include <stdio.h>
+#include <errno.h>
 
-#include <QtGui>
+#if (QT_VERSION >= 0x050000)
+   #include <QtWidgets> //lint !e537 Repeated include
+#else
+   #include <QtGui>     //lint !e537 Repeated include
+#endif
 
 #include "config.h"
 #include "main.h"
@@ -69,36 +75,14 @@ int UtilCalcDecimals (t_uint64 Value)
    return Str.length();
 }
 
-bool UtilIsZeroOld (unsigned char *pData, unsigned int DataLen)
-{
-   long long          *pBuff    = (long long *)pData;   //lint !e826   Suspicious pointer-to-pointer conversion
-   const unsigned int   CmpSize = sizeof (long long);   // 64 bit operations for optimal performance on amd64 processors
-
-   while (DataLen >= CmpSize)
-   {
-      if (*pBuff++)
-        return false;
-      DataLen -= CmpSize;
-   }
-
-   pData = (unsigned char *) pBuff;
-   while (DataLen--)
-   {
-      if (*pData++)
-         return false;
-   }
-
-   return true;
-}
-
 bool UtilIsZero (unsigned char *pData, unsigned int DataLen)
 {
    unsigned int ToCompare;
    unsigned int Remaining = DataLen;
    bool         IsZero    = true;
-   
+
    while (Remaining)
-   { 
+   {
       ToCompare = GETMIN(Remaining, UtilZeroBlockSize);
       IsZero = (memcmp (pData, pUtilZeroBlock, ToCompare) == 0);
       if (!IsZero)
@@ -130,7 +114,7 @@ unsigned long long UtilGetInstalledRAM (void)
    }
    else
    {
-      Bytes = (unsigned long long) sysconf(_SC_PHYS_PAGES) * 
+      Bytes = (unsigned long long) sysconf(_SC_PHYS_PAGES) *
               (unsigned long long) sysconf(_SC_PAGESIZE  );
    }
 
@@ -200,6 +184,93 @@ QString UtilSizeToHuman (unsigned long long Size, bool SI, int FracLen, int Unit
    return SizeHuman;
 }
 
+// UtilClose is wrapper and replacement for fclose. UtilClose was added because of rare
+// fclose problems when writing to network paths.
+
+#ifdef UTIL_CLOSE_OLD
+//#define UTIL_EMULATE_CLOSE_ERROR
+
+int UtilClose (FILE *pFile)           // This old function retries the close operation several times in case of errors. It was found
+{                                     // that this is not the right to go as guymager may hang when calling fclose a second time if
+   const int MaxRetries   = 10;       // the first call was unsuccessful.
+   const int SleepSeconds =  5;
+   int       rc, err;
+
+   for (int i=0;;i++)
+   {
+      #ifdef UTIL_EMULATE_CLOSE_ERROR
+         #warning "Debugging flag UTIL_EMULATE_CLOSE_ERROR is active"
+         static int CloseErrorCount=0;
+         if ((CloseErrorCount>=3) && (CloseErrorCount<=5))
+              rc = -1;
+         else rc = fclose (pFile);
+         CloseErrorCount++;
+      #else
+         rc = fclose (pFile);
+      #endif
+
+      if (rc==0)
+      {
+         if (i>0)
+            LOG_INFO ("fclose successful after %d tries", i+1)
+         break;
+      }
+      err = errno;
+      LOG_INFO ("fclose returned %d (errno %d - %s)", rc, err, strerror(err))
+
+      if (i>=MaxRetries)
+      {
+         LOG_ERROR ("Too many fclose errors, giving up!")
+         break;
+      }
+      sleep (SleepSeconds);
+   }
+
+   return rc;
+}
+
+#else
+
+int UtilClose (FILE *pFile)
+{
+   int ret;
+   int err;
+
+
+   #define LOG_FUNCTION_ERROR(FnName) \
+   {                                  \
+      err = errno;                    \
+      LOG_ERROR ("%s returned %d (errno %d - %s)", FnName, ret, err, strerror(err)) \
+   }
+
+   if CONFIG (AvoidCifsProblems)
+   {
+      ret = fflush (pFile);
+      if (ret)
+         LOG_FUNCTION_ERROR ("fflush")
+
+      ret = fileno (pFile);
+      if (ret == -1)
+         LOG_FUNCTION_ERROR ("fileno")
+      else
+      {
+         ret = fsync (ret);
+         if (ret == -1)
+            LOG_FUNCTION_ERROR ("fsync")
+      }
+   }
+
+   ret = fclose (pFile);
+   if (ret)
+      LOG_FUNCTION_ERROR ("fclose")
+
+   #undef LOG_FUNCTION_ERROR
+
+   return ret;
+}
+
+#endif
+
 t_UtilMem::t_UtilMem()
 {
    oSize = 0;
@@ -248,16 +319,16 @@ int t_UtilMem::Set (const char *pStr)
 
 
 APIRET UtilInit (void)
-{   
+{
    int MaxFifoBockSize;
-   
+
    MaxFifoBockSize = GETMAX(CONFIG(FifoBlockSizeEWF), CONFIG(FifoBlockSizeAFF));
-   
+
    UtilZeroBlockSize = GETMIN(UTIL_ZEROBLOCK_MAXSIZE, MaxFifoBockSize);
 
    pUtilZeroBlock = (char *) malloc (UtilZeroBlockSize);
    memset(pUtilZeroBlock, 0, UtilZeroBlockSize);
-   
+
    CHK (TOOL_ERROR_REGISTER_CODE (ERROR_UTIL_FREESPACE_UNKNOWN))
 
    return NO_ERROR;
